@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: backgammon.h,v 1.458 2015/10/08 00:34:36 mdpetch Exp $
+ * $Id: backgammon.h,v 1.460 2016/08/28 22:31:57 plm Exp $
  */
 
 #ifndef BACKGAMMON_H
@@ -373,7 +373,7 @@ extern int log_rollouts;
 extern int nThreadPriority;
 extern int nToolbarStyle;
 extern int nTutorSkillCurrent;
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
 extern int fSync;
 extern int fResetSync;
 #endif
@@ -437,8 +437,6 @@ extern char *GetInput(char *szPrompt);
 extern char *GetLuckAnalysis(const matchstate * pms, float rLuck);
 extern const char *GetMoveString(moverecord * pmr, int *pPlayer, gboolean addSkillMarks);
 extern double get_time(void);
-extern char *locale_from_utf8(const char *sz);
-extern char *locale_to_utf8(const char *sz);
 extern char *NextToken(char **ppch);
 extern char *NextTokenGeneral(char **ppch, const char *szTokens);
 extern char *SetupLanguage(const char *newLangCode);
@@ -508,6 +506,7 @@ extern void show_bearoff(TanBoard an, char *sz);
 extern void ShowBoard(void);
 extern void show_keith(TanBoard an, char *sz);
 extern void show_kleinman(TanBoard an, char *sz);
+extern void show_isight(TanBoard an, char *sz);
 extern void show_thorp(TanBoard an, char *sz);
 extern void TextToClipboard(const char *sz);
 extern void UpdateSettings(void);
@@ -951,6 +950,7 @@ extern void CommandShowGeometry(char *);
 extern void CommandShowJacoby(char *);
 extern void CommandShowKeith(char *);
 extern void CommandShowKleinman(char *);
+extern void CommandShowIsight(char *);
 extern void CommandShowLang(char *);
 extern void CommandShowManualAbout(char *);
 extern void CommandShowManualWeb(char *);
@@ -1000,8 +1000,6 @@ extern int CheckGameExists(void);
 extern void pmr_cubedata_set(moverecord * pmr, evalsetup * es, float output[2][NUM_ROLLOUT_OUTPUTS],
                              float stddev[2][NUM_ROLLOUT_OUTPUTS]);
 extern void pmr_movelist_set(moverecord * pmr, evalsetup * pes, movelist * pml);
-extern void current_pmr_cubedata_update(evalsetup * pes, float output[][NUM_ROLLOUT_OUTPUTS],
-                                        float stddev[][NUM_ROLLOUT_OUTPUTS]);
 extern listOLD *game_add_pmr_hint(listOLD * plGame);
 extern void game_remove_pmr_hint(listOLD * pl_hint);
 extern gboolean game_is_last(listOLD * plGame);
