@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: bearoff.c,v 1.99 2015/07/31 23:40:22 mdpetch Exp $
+ * $Id: bearoff.c,v 1.103 2017/09/30 21:53:50 plm Exp $
  */
 #include "config.h"
 /*must be first here because of strange warning from mingw */
@@ -501,22 +501,22 @@ BearoffStatus(const bearoffcontext * pbc, char *sz)
     /* Title */
     if (pbc->bt == BEAROFF_HYPERGAMMON) {
         if (pbc->p)
-            sprintf(buf, _("In memory 2-sided exact %d-chequer Hypergammon database evaluator"), pbc->nChequers);
+            sprintf(buf, _("In memory 2-sided exact %u-chequer Hypergammon database evaluator"), pbc->nChequers);
         else
-            sprintf(buf, _("On disk 2-sided exact %d-chequer Hypergammon database evaluator"), pbc->nChequers);
+            sprintf(buf, _("On disk 2-sided exact %u-chequer Hypergammon database evaluator"), pbc->nChequers);
 
     } else {
         if (pbc->p)
-            sprintf(buf, _("In memory %d-sided bearoff database evaluator"), pbc->bt);
+            sprintf(buf, _("In memory %u-sided bearoff database evaluator"), pbc->bt);
         else
-            sprintf(buf, _("On disk %d-sided bearoff database evaluator"), pbc->bt);
+            sprintf(buf, _("On disk %u-sided bearoff database evaluator"), pbc->bt);
 
     }
     sz += sprintf(sz, " * %s\n", buf);
 
     sz += sprintf(sz, "   - %s\n", _("generated by GNU Backgammon"));
 
-    sprintf(buf, _("up to %d chequers on %d points (%d positions) per player"), pbc->nChequers, pbc->nPoints,
+    sprintf(buf, _("up to %u chequers on %u points (%u positions) per player"), pbc->nChequers, pbc->nPoints,
             Combination(pbc->nChequers + pbc->nPoints, pbc->nPoints));
     sz += sprintf(sz, "   - %s\n", buf);
 
@@ -729,7 +729,6 @@ BearoffClose(bearoffcontext * pbc)
     if (pbc->pf)
         fclose(pbc->pf);
 
-#if GLIB_CHECK_VERSION(2,8,0)
     if (pbc->map) {
 #if GLIB_CHECK_VERSION(2,22,0)
         g_mapped_file_unref(pbc->map);
@@ -738,7 +737,6 @@ BearoffClose(bearoffcontext * pbc)
 #endif
         pbc->p = NULL;
     }
-#endif
 
     if (pbc->p)
         free(pbc->p);
@@ -749,21 +747,19 @@ BearoffClose(bearoffcontext * pbc)
     g_free(pbc);
 }
 
-#if GLIB_CHECK_VERSION(2,8,0)
 static unsigned char *
 ReadIntoMemory(bearoffcontext * pbc)
 {
     GError *error = NULL;
     pbc->map = g_mapped_file_new(pbc->szFilename, FALSE, &error);
     if (!pbc->map) {
-        g_printerr(_("%s: Failed to map bearoffdatabase %s\n"), pbc->szFilename, error->message);
+        g_printerr(_("%s: Failed to map bearoff database %s\n"), pbc->szFilename, error->message);
         g_error_free(error);
         return NULL;
     }
     pbc->p = (unsigned char *) g_mapped_file_get_contents(pbc->map);
     return pbc->p;
 }
-#endif
 
 /*
  * Check whether this is a exact bearoff file 
@@ -884,7 +880,7 @@ BearoffInit(const char *szFilename, const int bo, void (*p) (unsigned int))
 
         pbc->nPoints = (unsigned) atoi(sz + 9);
         if (pbc->nPoints < 1 || pbc->nPoints >= 24) {
-            g_printerr("%s: %s\n (%s: %d)\n", szFilename, _("incomplete bearoff database"),
+            g_printerr("%s: %s\n (%s: %u)\n", szFilename, _("incomplete bearoff database"),
                        _("illegal number of points"), pbc->nPoints);
             InvalidDb(pbc);
             return NULL;
@@ -894,7 +890,7 @@ BearoffInit(const char *szFilename, const int bo, void (*p) (unsigned int))
 
         pbc->nChequers = (unsigned) atoi(sz + 12);
         if (pbc->nChequers < 1 || pbc->nChequers > 15) {
-            g_printerr("%s: %s\n (%s: %d)", szFilename, _("incomplete bearoff database"),
+            g_printerr("%s: %s\n (%s: %u)", szFilename, _("incomplete bearoff database"),
                        _("illegal number of chequers"), pbc->nChequers);
             InvalidDb(pbc);
             return NULL;
@@ -929,7 +925,6 @@ BearoffInit(const char *szFilename, const int bo, void (*p) (unsigned int))
      * read database into memory if requested 
      */
 
-#if GLIB_CHECK_VERSION(2,8,0)
     if (bo & (int) BO_IN_MEMORY) {
         fclose(pbc->pf);
         pbc->pf = NULL;
@@ -940,7 +935,7 @@ BearoffInit(const char *szFilename, const int bo, void (*p) (unsigned int))
                 return NULL;
             }
     }
-#endif
+
     return pbc;
 }
 
@@ -957,7 +952,7 @@ fnd(const float x, const float mu, const float sigma)
 
         float xm = (x - mu) / sigma;
 
-        return 1.0f / (sigma * sqrtf(2.0f * (float) G_PI) * expf(-xm * xm / 2.0f));
+        return 1.0f / (sigma * sqrtf(2.0f * (float) G_PI)) * expf(-xm * xm / 2.0f);
 
     }
 
