@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: misc3d.c,v 1.116 2016/05/11 21:33:09 plm Exp $
+ * $Id: misc3d.c,v 1.118 2016/08/28 22:24:49 plm Exp $
  */
 
 #include "config.h"
@@ -60,6 +60,8 @@ static idleFunc *pIdleFun;
 static BoardData *pIdleBD;
 Flag3d flag;                    /* Only one flag */
 
+static void SetupSimpleMatAlpha(Material * pMat, float r, float g, float b, float a);
+
 static gboolean
 idle(BoardData3d * bd3d)
 {
@@ -807,7 +809,7 @@ moveAlong(float d, PathType type, const float start[3], const float end[3], floa
 }
 
 /* Return v position, d distance along path p */
-int
+static int
 movePath(Path * p, float d, float *rotate, float v[3])
 {
     float done;
@@ -2310,7 +2312,7 @@ SetupMat(Material * pMat, float r, float g, float b, float dr, float dg, float d
     pMat->pTexture = NULL;
 }
 
-void
+static void
 SetupSimpleMatAlpha(Material * pMat, float r, float g, float b, float a)
 {
     SetupMat(pMat, r, g, b, r, g, b, 0.f, 0.f, 0.f, 0, a);
@@ -2410,7 +2412,7 @@ InitBoard3d(BoardData * bd, BoardData3d * bd3d)
     bd->bd3d->fBuffers = FALSE;
 }
 
-#if HAVE_LIBPNG
+#if defined(HAVE_LIBPNG)
 
 void
 GenerateImage3d(const char *szName, unsigned int nSize, unsigned int nSizeX, unsigned int nSizeY)
