@@ -12,7 +12,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: dbprovider.h,v 1.17 2013/06/16 02:16:10 mdpetch Exp $
+ * $Id: dbprovider.h,v 1.18 2016/04/08 05:24:53 plm Exp $
  */
 
 #ifndef DBPROVIDER_H
@@ -50,11 +50,11 @@ typedef struct _DBProvider {
 
 typedef enum _DBProviderType {
     INVALID_PROVIDER = -1,
-#if USE_SQLITE
+#if defined(USE_SQLITE)
     SQLITE,
 #endif
-#if USE_PYTHON
-#if !USE_SQLITE
+#if defined(USE_PYTHON)
+#if !defined(USE_SQLITE)
     PYTHON_SQLITE,
 #endif
     PYTHON_MYSQL,
@@ -64,13 +64,13 @@ typedef enum _DBProviderType {
 #endif
 } DBProviderType;
 
-#if USE_PYTHON
+#if defined(USE_PYTHON)
 #if !defined(WIN32)
 #define NUM_PROVIDERS 3
 #else
 #define NUM_PROVIDERS 2
 #endif
-#elif USE_SQLITE
+#elif defined(USE_SQLITE)
 #define NUM_PROVIDERS 1
 #else
 #define NUM_PROVIDERS 0
