@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: dice.c,v 1.97 2016/04/08 05:31:05 plm Exp $
+ * $Id: dice.c,v 1.99 2017/12/13 21:25:21 plm Exp $
  */
 
 #include "config.h"
@@ -596,6 +596,13 @@ InitRNGSeedLong(char *sz, rng rng, rngcontext * rngctx)
 }
 #endif
 
+static void
+CloseDiceFile(rngcontext * rngctx)
+{
+    if (rngctx->fDice)
+        fclose(rngctx->fDice);
+}
+
 extern void
 CloseRNG(const rng rngx, rngcontext * rngctx)
 {
@@ -707,7 +714,10 @@ extern void *
 InitRNG(unsigned long *pnSeed, int *pfInitFrom, const int fSet, const rng rngx)
 {
     int f = FALSE;
-    rngcontext *rngctx = g_new0(rngcontext, 1);
+    rngcontext *rngctx = g_try_new0(rngcontext, 1);
+
+    if (rngctx == NULL)
+        return NULL;
 
     /* misc. initialisation */
 
@@ -732,7 +742,6 @@ InitRNG(unsigned long *pnSeed, int *pfInitFrom, const int fSet, const rng rngx)
         *pfInitFrom = f;
 
     return rngctx;
-
 }
 
 extern int
@@ -837,14 +846,6 @@ OpenDiceFile(rngcontext * rngctx, const char *sz)
     return (rngctx->fDice = gnubg_g_fopen(sz, "r"));
 }
 
-extern void
-CloseDiceFile(rngcontext * rngctx)
-{
-    if (rngctx->fDice)
-        fclose(rngctx->fDice);
-}
-
-
 static unsigned int
 ReadDiceFile(rngcontext * rngctx)
 {
