@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: dice.h,v 1.34 2016/04/08 05:31:05 plm Exp $
+ * $Id: dice.h,v 1.35 2016/08/24 22:00:57 plm Exp $
  */
 
 #ifndef DICE_H
@@ -59,9 +59,6 @@ extern int InitRNGBBSFactors(char *sz0, char *sz1, rngcontext * rngctx);
 
 extern FILE *OpenDiceFile(rngcontext * rngctx, const char *sz);
 
-extern void
- CloseDiceFile(rngcontext * rngctx);
-
 extern char *GetDiceFileName(rngcontext * rngctx);
 
 #endif
