@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: eval.h,v 1.193 2016/05/11 21:33:08 plm Exp $
+ * $Id: eval.h,v 1.197 2017/01/05 07:50:16 plm Exp $
  */
 
 #ifndef EVAL_H
@@ -92,6 +92,7 @@ typedef struct {
     unsigned int nPlies:4;
     unsigned int fUsePrune:1;
     unsigned int fDeterministic:1;
+    unsigned int :25;		/* padding */
     float rNoise;               /* standard deviation */
 } evalcontext;
 
@@ -131,8 +132,8 @@ typedef struct {
     unsigned short nLate;       /* switch evaluations on move nLate of game */
     rng rngRollout;
     unsigned long nSeed;
-    unsigned int nMinimumGames; /* but always do at least this many */
-    float rStdLimit;           /* stop when abs( value / std ) < this */
+    unsigned int nMinimumGames; /* always do at least this many */
+    float rStdLimit;            /* stop when std < this */
     unsigned int nMinimumJsdGames;
     float rJsdLimit;
     unsigned int nGamesDone;
@@ -380,6 +381,9 @@ extern int
 extern int
  KeithCount(const TanBoard anBoard, int pn[2]);
 
+extern int
+ IsightCount(const TanBoard anBoard, int pn[2]);
+
 extern int
  DumpPosition(const TanBoard anBoard, char *szOutput,
              const evalcontext * pec, cubeinfo * pci, int fOutputMWC,
@@ -425,10 +429,6 @@ extern int
  SetCubeInfoMoney(cubeinfo * pci, const int nCube, const int fCubeOwner,
                  const int fMove, const int fJacoby, const int fBeavers, const bgvariation bgv);
 
-extern int
- SetCubeInfoMatch(cubeinfo * pci, const int nCube, const int fCubeOwner,
-                 const int fMove, const int nMatchTo, const int anScore[2], const int fCrawford, const bgvariation bgv);
-
 extern int
  SetCubeInfo(cubeinfo * pci, const int nCube, const int fCubeOwner,
             const int fMove, const int nMatchTo, const int anScore[2],
@@ -443,9 +443,6 @@ extern void
 extern void
  SanityCheck(const TanBoard anBoard, float arOutput[]);
 
-extern int
- EvalBearoff1(const TanBoard anBoard, float arOutput[], const bgvariation bgv, NNState * nnStates);
-
 extern int
  EvalOver(const TanBoard anBoard, float arOutput[], const bgvariation bgv, NNState * nnStates);
 
@@ -484,9 +481,6 @@ extern int
 extern int
  cmp_evalcontext(const evalcontext * pec1, const evalcontext * pec2);
 
-extern int
- cmp_rolloutcontext(const rolloutcontext * prc1, const rolloutcontext * prc2);
-
 extern char
 *GetCubeRecommendation(const cubedecision cd);
 
@@ -497,9 +491,6 @@ extern int
  getCurrentGammonRates(float aarRates[2][2],
                       float arOutput[], const TanBoard anBoard, cubeinfo * pci, const evalcontext * pec);
 
-extern void
- calculate_gammon_rates(float aarRates[2][2], float arOutput[], cubeinfo * pci);
-
 extern void
  getMoneyPoints(float aaarPoints[2][7][2], const int fJacoby, const int fBeavers, float aarRates[2][2]);
 
@@ -531,9 +522,6 @@ extern int
 extern unsigned int
  locateMove(const TanBoard anBoard, const int anMove[8], const movelist * pml);
 
-extern int
- MoveKey(const TanBoard anBoard, const int anMove[8], positionkey * pkey);
-
 extern int
  equal_movefilter(const int i, const movefilter amf1[MAX_FILTER_PLIES], const movefilter amf2[MAX_FILTER_PLIES]);
 
@@ -549,9 +537,6 @@ extern int
 extern void
  baseInputs(const TanBoard anBoard, float arInput[]);
 
-extern void
- CalculateRaceInputs(const TanBoard anBoard, float inputs[]);
-
 extern int CompareMoves(const move * pm0, const move * pm1);
 extern float EvalEfficiency(const TanBoard anBoard, positionclass pc);
 extern float Cl2CfMoney(float arOutput[NUM_OUTPUTS], cubeinfo * pci, float rCubeX);
