@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: export.c,v 1.86 2015/08/28 22:31:09 plm Exp $
+ * $Id: export.c,v 1.88 2017/04/27 20:31:15 plm Exp $
  */
 
 #include "config.h"
@@ -29,7 +29,7 @@
 #include <string.h>
 #include "glib-ext.h"
 
-#if HAVE_LIBPNG
+#if defined(HAVE_LIBPNG)
 #include <png.h>
 #endif
 
@@ -43,7 +43,7 @@
 #include "boardpos.h"
 #include "boarddim.h"
 
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
 #include <cairo.h>
 #include <cairo-svg.h>
 #include <cairo-pdf.h>
@@ -63,7 +63,7 @@
  *   iGame: game number
  *
  * Garbage collect:
- *   Caller must free returned pointer if not NULL
+ *   Caller must g_free returned pointer
  * 
  */
 
@@ -88,7 +88,9 @@ filename_from_iGame(const char *szBase, const int iGame)
     }
 }
 
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
+
+/* Caller must g_free returned pointer */
 static gchar *
 export_get_filename(char *sz)
 {
@@ -248,7 +250,7 @@ draw_cairo_pages(cairo_t * cairo, listOLD * game_ptr)
 extern void
 CommandExportPositionSVG(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     gchar *filename;
     int move_nr;
     int game_nr;
@@ -264,10 +266,12 @@ CommandExportPositionSVG(char *sz)
         return;
     pmr = export_get_moverecord(&game_nr, &move_nr);
     if (!pmr) {
+        g_free(filename);
         outputerrf(_("Cannot create export for this move"));
         return;
     }
     surface = cairo_svg_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT / 2.0);
+    g_free(filename);
     if (surface) {
         cairo = cairo_create(surface);
         draw_simple_board_on_cairo(&ms, pmr, move_nr, game_nr, cairo, SIZE_1PERPAGE);
@@ -281,7 +285,7 @@ CommandExportPositionSVG(char *sz)
 extern void
 CommandExportPositionPDF(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     gchar *filename;
     int move_nr;
     int game_nr;
@@ -297,10 +301,12 @@ CommandExportPositionPDF(char *sz)
         return;
     pmr = export_get_moverecord(&game_nr, &move_nr);
     if (!pmr) {
+        g_free(filename);
         outputerrf(_("Cannot create export for this move"));
         return;
     }
     surface = cairo_pdf_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
     if (surface) {
         cairo = cairo_create(surface);
         draw_simple_board_on_cairo(&ms, pmr, move_nr, game_nr, cairo, SIZE_1PERPAGE);
@@ -314,7 +320,7 @@ CommandExportPositionPDF(char *sz)
 extern void
 CommandExportPositionPS(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     gchar *filename;
     int move_nr;
     int game_nr;
@@ -330,11 +336,13 @@ CommandExportPositionPS(char *sz)
         return;
     pmr = export_get_moverecord(&game_nr, &move_nr);
     if (!pmr) {
+        g_free(filename);
         outputerrf(_("Cannot create export for this move"));
         return;
     }
 
     surface = cairo_ps_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
     if (surface) {
         cairo = cairo_create(surface);
         draw_simple_board_on_cairo(&ms, pmr, move_nr, game_nr, cairo, SIZE_1PERPAGE);
@@ -348,7 +356,7 @@ CommandExportPositionPS(char *sz)
 extern void
 CommandExportGamePDF(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     gchar *filename;
     cairo_surface_t *surface;
     cairo_t *cairo;
@@ -360,6 +368,7 @@ CommandExportGamePDF(char *sz)
     if (!filename)
         return;
     surface = cairo_pdf_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
     if (surface) {
         cairo = cairo_create(surface);
         draw_cairo_pages(cairo, plGame);
@@ -373,7 +382,7 @@ CommandExportGamePDF(char *sz)
 extern void
 CommandExportGamePS(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     gchar *filename;
     cairo_surface_t *surface;
     cairo_t *cairo;
@@ -385,6 +394,7 @@ CommandExportGamePS(char *sz)
     if (!filename)
         return;
     surface = cairo_ps_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
     if (surface) {
         cairo = cairo_create(surface);
         draw_cairo_pages(cairo, plGame);
@@ -398,7 +408,7 @@ CommandExportGamePS(char *sz)
 extern void
 CommandExportMatchPDF(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     listOLD *pl;
     int nGames = 0;
     int i;
@@ -411,6 +421,7 @@ CommandExportMatchPDF(char *sz)
     if (!filename)
         return;
     surface = cairo_pdf_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
     if (surface) {
         for (pl = lMatch.plNext; pl != &lMatch; pl = pl->plNext, nGames++);
 
@@ -428,7 +439,7 @@ CommandExportMatchPDF(char *sz)
 extern void
 CommandExportMatchPS(char *sz)
 {
-#if HAVE_PANGOCAIRO
+#if defined(HAVE_PANGOCAIRO)
     listOLD *pl;
     int nGames = 0;
     int i;
@@ -441,6 +452,7 @@ CommandExportMatchPS(char *sz)
     if (!filename)
         return;
     surface = cairo_ps_surface_create(filename, SIMPLE_BOARD_WIDTH, SIMPLE_BOARD_HEIGHT);
+    g_free(filename);
     if (surface) {
         for (pl = lMatch.plNext; pl != &lMatch; pl = pl->plNext, nGames++);
 
@@ -455,7 +467,7 @@ CommandExportMatchPS(char *sz)
         outputerrf(_("Failed to create cairo surface for %s"), sz);
 }
 
-#if HAVE_LIBPNG
+#if defined(HAVE_LIBPNG)
 
 /* size of html images in steps of BOARD_WIDTH x BOARD_HEIGHT
  * as defined in boarddim.h */
@@ -659,7 +671,7 @@ CommandExportPositionPNG(char *sz)
 
     /* generate PNG image */
 
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
     if (GetMainAppearance()->fDisplayType == DT_3D) {
         GenerateImage3d(sz, exsExport.nPNGSize, BOARD_WIDTH, BOARD_HEIGHT);
     } else
@@ -766,11 +778,11 @@ ExportSnowieTxt(char *sz, const matchstate * pms)
 
     /* chequers on the bar for opponent */
 
-    sz += sprintf(sz, "%d;", pms->anBoard[1][24]);
+    sz += sprintf(sz, "%u;", pms->anBoard[1][24]);
 
     /* dice */
 
-    sprintf(sz, "%d;%d;", (pms->anDice[0] > 0) ? pms->anDice[0] : 0, (pms->anDice[1] > 0) ? pms->anDice[1] : 0);
+    sprintf(sz, "%u;%u;", (pms->anDice[0] > 0) ? pms->anDice[0] : 0, (pms->anDice[1] > 0) ? pms->anDice[1] : 0);
 
 }
 
