@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: format.c,v 1.49 2015/01/18 18:52:48 plm Exp $
+ * $Id: format.c,v 1.57 2016/05/07 21:14:28 plm Exp $
  */
 
 #include "config.h"
@@ -35,7 +35,10 @@
 int fOutputMWC = FALSE;
 int fOutputWinPC = FALSE;
 int fOutputMatchPC = TRUE;
-unsigned int fOutputDigits = 3;
+
+#define OUTPUT_SZ_LENGTH (5 + MAX_OUTPUT_DIGITS)
+int fOutputDigits = 3;
+
 float rErrorRateFactor = 1000.0f;
 
 typedef int (*classdumpfunc) (const TanBoard anBoard, char *szOutput, const bgvariation bgv);
@@ -50,7 +53,6 @@ OutputRolloutResult(const char *szIndent,
 
     static char sz[1024];
     int ici;
-    char *pc;
 
     strcpy(sz, "");
 
@@ -61,7 +63,7 @@ OutputRolloutResult(const char *szIndent,
         if (asz && *asz[ici]) {
             if (szIndent && *szIndent)
                 strcat(sz, szIndent);
-            sprintf(pc = strchr(sz, 0), "%s:\n", asz[ici]);
+            sprintf(strchr(sz, 0), "%s:\n", asz[ici]);
         }
 
         /* output */
@@ -110,13 +112,12 @@ OutputEvalContext(const evalcontext * pec, const int fChequer)
 {
 
     static char sz[1024];
-    char *pc;
     int i;
 
     sprintf(sz, "%u-%s %s", pec->nPlies, _("ply"), (!fChequer || pec->fCubeful) ? _("cubeful") : _("cubeless"));
 
     if (pec->fUsePrune) {
-        sprintf(pc = strchr(sz, 0), " prune");
+        sprintf(strchr(sz, 0), " prune");
     }
 
     if (fChequer && pec->nPlies) {
@@ -124,12 +125,12 @@ OutputEvalContext(const evalcontext * pec, const int fChequer)
     }
 
     if (pec->rNoise > 0.0f)
-        sprintf(pc = strchr(sz, 0), ", noise %0.3g (%s)", pec->rNoise, pec->fDeterministic ? "d" : "nd");
+        sprintf(strchr(sz, 0), ", noise %0.3g (%s)", pec->rNoise, pec->fDeterministic ? "d" : "nd");
 
     for (i = 0; i < NUM_SETTINGS; i++)
 
         if (!cmp_evalcontext(&aecSettings[i], pec)) {
-            sprintf(pc = strchr(sz, 0), " [%s]", Q_(aszSettings[i]));
+            sprintf(strchr(sz, 0), " [%s]", Q_(aszSettings[i]));
             break;
         }
 
@@ -251,7 +252,8 @@ OutputMoveFilterPly(const char *szIndent, const int nPlies, const movefilter aam
 static void
 OutputEvalContextsForRollout(char *sz, const char *szIndent,
                              const evalcontext aecCube[2],
-                             const evalcontext aecChequer[2], const movefilter aaamf[2][MAX_FILTER_PLIES][MAX_FILTER_PLIES])
+                             const evalcontext aecChequer[2],
+                             const movefilter aaamf[2][MAX_FILTER_PLIES][MAX_FILTER_PLIES])
 {
 
     int fCube = !cmp_evalcontext(&aecCube[0], &aecCube[1]);
@@ -358,8 +360,8 @@ OutputRolloutContext(const char *szIndent, const rolloutcontext * prc)
 
     if (prc->fStopOnSTD && !prc->fStopOnJsd) {
         sprintf(strchr(sz, 0),
-                _("Stop when std.errs. are small enough: ratio "
-                  "%.4g (min. %d games)"), prc->rStdLimit, prc->nMinimumGames);
+                _("Stop when std.errs. are small enough: limit "
+                  "%.4f (min. %u games)"), prc->rStdLimit, prc->nMinimumGames);
         strcat(sz, "\n");
     }
 
@@ -367,7 +369,7 @@ OutputRolloutContext(const char *szIndent, const rolloutcontext * prc)
     if (prc->fStopOnJsd) {
         sprintf(strchr(sz, 0),
                 _("Stop when best play is enough JSDs ahead: limit "
-                  "%.4g (min. %d games)"), prc->rJsdLimit, prc->nMinimumJsdGames);
+                  "%.4f (min. %u games)"), prc->rJsdLimit, prc->nMinimumJsdGames);
         strcat(sz, "\n");
     }
 
@@ -385,8 +387,7 @@ OutputRolloutContext(const char *szIndent, const rolloutcontext * prc)
         sprintf(strchr(sz, 0), _("Different evaluations after %d plies:"), prc->nLate);
         strcat(sz, "\n");
 
-        OutputEvalContextsForRollout(sz, szIndent,
-                                     prc->aecCubeLate, prc->aecChequerLate, prc->aaamfLate);
+        OutputEvalContextsForRollout(sz, szIndent, prc->aecCubeLate, prc->aecChequerLate, prc->aaamfLate);
 
 
     }
@@ -412,13 +413,13 @@ extern char *
 OutputEquity(const float r, const cubeinfo * pci, const int f)
 {
 
-    static char sz[9];
+    static char sz[OUTPUT_SZ_LENGTH];
 
-    if (!pci->nMatchTo || (pci->nMatchTo && !fOutputMWC)) {
+    if (!pci->nMatchTo || !fOutputMWC) {
         if (f)
-            sprintf(sz, "%+*.*f", fOutputDigits + 4, fOutputDigits, r);
+            sprintf(sz, "%+*.*f", fOutputDigits + 3, fOutputDigits, r);
         else
-            sprintf(sz, "%*.*f", fOutputDigits + 4, fOutputDigits, r);
+            sprintf(sz, "%*.*f", fOutputDigits + 2, fOutputDigits, r);
     } else {
         if (fOutputMatchPC) {
             sprintf(sz, "%*.*f%%", fOutputDigits + 3, fOutputDigits > 1 ? fOutputDigits - 1 : 0,
@@ -437,14 +438,14 @@ extern char *
 OutputMoneyEquity(const float ar[], const int f)
 {
 
-    static char sz[9];
+    static char sz[OUTPUT_SZ_LENGTH];
     float eq = 2.0f * ar[OUTPUT_WIN] - 1.0f + ar[OUTPUT_WINGAMMON] + ar[OUTPUT_WINBACKGAMMON] -
         ar[OUTPUT_LOSEGAMMON] - ar[OUTPUT_LOSEBACKGAMMON];
 
     if (f)
-        sprintf(sz, "%+*.*f", fOutputDigits + 4, fOutputDigits, eq);
+        sprintf(sz, "%+*.*f", fOutputDigits + 3, fOutputDigits, eq);
     else
-        sprintf(sz, "%*.*f", fOutputDigits + 4, fOutputDigits, eq);
+        sprintf(sz, "%*.*f", fOutputDigits + 2, fOutputDigits, eq);
 
 
     return sz;
@@ -470,13 +471,13 @@ extern char *
 OutputEquityScale(const float r, const cubeinfo * pci, const cubeinfo * pciBase, const int f)
 {
 
-    static char sz[9];
+    static char sz[OUTPUT_SZ_LENGTH];
 
     if (!pci->nMatchTo) {
         if (f)
-            sprintf(sz, "%+*.*f", fOutputDigits + 4, fOutputDigits, pci->nCube / pciBase->nCube * r);
+            sprintf(sz, "%+*.*f", fOutputDigits + 3, fOutputDigits, pci->nCube / pciBase->nCube * r);
         else
-            sprintf(sz, "%*.*f", fOutputDigits + 4, fOutputDigits, pci->nCube / pciBase->nCube * r);
+            sprintf(sz, "%*.*f", fOutputDigits + 2, fOutputDigits, pci->nCube / pciBase->nCube * r);
     } else {
 
         if (fOutputMWC) {
@@ -490,9 +491,9 @@ OutputEquityScale(const float r, const cubeinfo * pci, const cubeinfo * pciBase,
 
         } else {
             if (f)
-                sprintf(sz, "%+*.*f", fOutputDigits + 4, fOutputDigits, mwc2eq(eq2mwc(r, pci), pciBase));
+                sprintf(sz, "%+*.*f", fOutputDigits + 3, fOutputDigits, mwc2eq(eq2mwc(r, pci), pciBase));
             else
-                sprintf(sz, "%*.*f", fOutputDigits + 4, fOutputDigits, se_mwc2eq(se_eq2mwc(r, pci), pciBase));
+                sprintf(sz, "%*.*f", fOutputDigits + 2, fOutputDigits, se_mwc2eq(se_eq2mwc(r, pci), pciBase));
         }
 
 
@@ -520,10 +521,10 @@ extern char *
 OutputEquityDiff(const float r1, const float r2, const cubeinfo * pci)
 {
 
-    static char sz[9];
+    static char sz[OUTPUT_SZ_LENGTH];
 
-    if (!pci->nMatchTo || (pci->nMatchTo && !fOutputMWC)) {
-        sprintf(sz, "%+*.*f", fOutputDigits + 4, fOutputDigits, r1 - r2);
+    if (!pci->nMatchTo || !fOutputMWC) {
+        sprintf(sz, "%+*.*f", fOutputDigits + 3, fOutputDigits, r1 - r2);
     } else {
         if (fOutputMatchPC) {
             sprintf(sz, "%*.*f%%", fOutputDigits + 3, fOutputDigits > 1 ? fOutputDigits - 1 : 0,
@@ -551,20 +552,20 @@ extern char *
 OutputMWC(const float r, const cubeinfo * pci, const int f)
 {
 
-    static char sz[9];
+    static char sz[OUTPUT_SZ_LENGTH];
 
     if (!pci->nMatchTo) {
         if (f)
-            sprintf(sz, "%+*.*f", fOutputDigits + 4, fOutputDigits, r);
+            sprintf(sz, "%+*.*f", fOutputDigits + 3, fOutputDigits, r);
         else
-            sprintf(sz, "%*.*f", fOutputDigits + 4, fOutputDigits, r);
+            sprintf(sz, "%*.*f", fOutputDigits + 2, fOutputDigits, r);
     } else {
 
         if (!fOutputMWC) {
             if (f)
-                sprintf(sz, "%+*.*f", fOutputDigits + 4, fOutputDigits, mwc2eq(r, pci));
+                sprintf(sz, "%+*.*f", fOutputDigits + 3, fOutputDigits, mwc2eq(r, pci));
             else
-                sprintf(sz, "%*.*f", fOutputDigits + 4, fOutputDigits, se_mwc2eq(r, pci));
+                sprintf(sz, "%*.*f", fOutputDigits + 3, fOutputDigits, se_mwc2eq(r, pci));
         } else if (fOutputMatchPC) {
             sprintf(sz, "%*.*f%%", fOutputDigits + 3, fOutputDigits > 1 ? fOutputDigits - 1 : 0, 100.0f * r);
         } else {
@@ -584,7 +585,7 @@ extern char *
 OutputPercent(const float r)
 {
 
-    static char sz[9];
+    static char sz[OUTPUT_SZ_LENGTH];
 
     if (fOutputWinPC) {
         sprintf(sz, "%*.*f", fOutputDigits + 2, fOutputDigits > 2 ? fOutputDigits - 2 : 0, 100.0 * r);
@@ -654,7 +655,6 @@ OutputCubeAnalysisFull(float aarOutput[2][NUM_ROLLOUT_OUTPUTS],
     float arDouble[4];
 
     static char sz[4096];
-    char *pc;
 
 
     strcpy(sz, "");
@@ -678,14 +678,14 @@ OutputCubeAnalysisFull(float aarOutput[2][NUM_ROLLOUT_OUTPUTS],
 
         /* missed double */
 
-        sprintf(pc = strchr(sz, 0), "%s (%s)!\n",
+        sprintf(strchr(sz, 0), "%s (%s)!\n",
                 _("Alert: missed double"),
                 OutputEquityDiff(arDouble[OUTPUT_NODOUBLE],
                                  (arDouble[OUTPUT_TAKE] >
                                   arDouble[OUTPUT_DROP]) ? arDouble[OUTPUT_DROP] : arDouble[OUTPUT_TAKE], pci));
 
         if (badSkill(stDouble))
-            sprintf(pc = strchr(sz, 0), " [%s]", gettext(aszSkillType[stDouble]));
+            sprintf(strchr(sz, 0), " [%s]", gettext(aszSkillType[stDouble]));
 
     }
 
@@ -697,11 +697,11 @@ OutputCubeAnalysisFull(float aarOutput[2][NUM_ROLLOUT_OUTPUTS],
 
         /* wrong take */
 
-        sprintf(pc = strchr(sz, 0), "%s (%s)!\n",
+        sprintf(strchr(sz, 0), "%s (%s)!\n",
                 _("Alert: wrong take"), OutputEquityDiff(arDouble[OUTPUT_DROP], arDouble[OUTPUT_TAKE], pci));
 
         if (badSkill(stTake))
-            sprintf(pc = strchr(sz, 0), " [%s]", gettext(aszSkillType[stTake]));
+            sprintf(strchr(sz, 0), " [%s]", gettext(aszSkillType[stTake]));
 
     }
 
@@ -713,11 +713,11 @@ OutputCubeAnalysisFull(float aarOutput[2][NUM_ROLLOUT_OUTPUTS],
 
         /* wrong pass */
 
-        sprintf(pc = strchr(sz, 0), "%s (%s)!\n",
+        sprintf(strchr(sz, 0), "%s (%s)!\n",
                 _("Alert: wrong pass"), OutputEquityDiff(arDouble[OUTPUT_TAKE], arDouble[OUTPUT_DROP], pci));
 
         if (badSkill(stTake))
-            sprintf(pc = strchr(sz, 0), " [%s]", gettext(aszSkillType[stTake]));
+            sprintf(strchr(sz, 0), " [%s]", gettext(aszSkillType[stTake]));
 
     }
 
@@ -733,26 +733,26 @@ OutputCubeAnalysisFull(float aarOutput[2][NUM_ROLLOUT_OUTPUTS],
 
         /* wrong double */
 
-        sprintf(pc = strchr(sz, 0), "%s (%s)!\n",
+        sprintf(strchr(sz, 0), "%s (%s)!\n",
                 _("Alert: wrong double"),
                 OutputEquityDiff((arDouble[OUTPUT_TAKE] >
                                   arDouble[OUTPUT_DROP]) ?
                                  arDouble[OUTPUT_DROP] : arDouble[OUTPUT_TAKE], arDouble[OUTPUT_NODOUBLE], pci));
 
         if (badSkill(stDouble))
-            sprintf(pc = strchr(sz, 0), " [%s]", gettext(aszSkillType[stDouble]));
+            sprintf(strchr(sz, 0), " [%s]", gettext(aszSkillType[stDouble]));
 
     }
 
     if ((badSkill(stDouble) || badSkill(stTake)) && !fAnno) {
 
         if (badSkill(stDouble)) {
-            sprintf(pc = strchr(sz, 0), _("Alert: double decision marked %s"), gettext(aszSkillType[stDouble]));
+            sprintf(strchr(sz, 0), _("Alert: double decision marked %s"), gettext(aszSkillType[stDouble]));
             strcat(sz, "\n");
         }
 
         if (badSkill(stTake)) {
-            sprintf(pc = strchr(sz, 0), _("Alert: take decision marked %s"), gettext(aszSkillType[stTake]));
+            sprintf(strchr(sz, 0), _("Alert: take decision marked %s"), gettext(aszSkillType[stTake]));
             strcat(sz, "\n");
         }
 
@@ -805,7 +805,7 @@ OutputCubeAnalysis(float aarOutput[2][NUM_ROLLOUT_OUTPUTS],
 
     if (pci->nMatchTo)
         sprintf(strchr(sz, 0), " %s %s (%s: %s)\n",
-                (!pci->nMatchTo || (pci->nMatchTo && !fOutputMWC)) ?
+                (!pci->nMatchTo || !fOutputMWC) ?
                 _("cubeless equity") : _("cubeless MWC"),
                 OutputEquity(aarOutput[0][OUTPUT_EQUITY], pci, TRUE),
                 _("Money"), OutputMoneyEquity(aarOutput[0], TRUE));
@@ -1112,7 +1112,7 @@ DumpPosition(const TanBoard anBoard, char *szOutput,
             "\n"
             "        %-7s %-7s %-7s %-7s %-7s %-9s %-9s\n",
             _("Win"), _("W(g)"), _("W(bg)"), _("L(g)"), _("L(bg)"),
-            (!pci->nMatchTo || (pci->nMatchTo && !fOutputMWC)) ? _("Equity") : _("MWC"), _("Cubeful"));
+            (!pci->nMatchTo || !fOutputMWC) ? _("Equity") : _("MWC"), _("Cubeful"));
 
     nPlies = pec->nPlies > 9 ? 9 : pec->nPlies;
 
