@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gnubgmodule.h,v 1.27 2013/07/18 02:01:24 mdpetch Exp $
+ * $Id: gnubgmodule.h,v 1.31 2014/08/07 21:51:48 mdpetch Exp $
  */
 
 #ifndef GNUBGMODULE_H
@@ -28,16 +28,11 @@
 /* needed for mingw inclusion of Python.h */
 #include <stdint.h>
 #endif
-#include <Python.h>
-extern PyObject *PythonGnubgModule(void);
 
-#if PY_VERSION_HEX < 0x02050000 && !defined(PY_SSIZE_T_MIN)
-typedef int Py_ssize_t;
-#define PY_SSIZE_T_MAX INT_MAX
-#define PY_SSIZE_T_MIN INT_MIN
-#endif                          /* PY_VERSION_CHK */
-extern PyObject *PythonGnubgModule();
-#endif                          /* USE_PYTHON */
+#include <Python.h>
+#include "pylocdefs.h"
+
+extern PyObject *PythonGnubgModule(void);
 
 #include "lib/simd.h"
 
@@ -48,5 +43,8 @@ extern void PythonShutdown(void);
 extern void PythonRun(const char *sz);
 extern int LoadPythonFile(const char *sz, int fQuiet);
 extern gint python_run_file(gpointer file);
+extern MOD_INIT(gnubg);
+
+#endif                          /* USE_PYTHON */
 
 #endif                          /* GNUBGMODULE_H */
