@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkcube.c,v 1.89 2016/01/25 21:34:54 plm Exp $
+ * $Id: gtkcube.c,v 1.92 2017/05/19 21:29:10 plm Exp $
  */
 
 #include "config.h"
@@ -379,7 +379,11 @@ CubeAnalysis(cubehintdata * pchd)
     pwFrame = gtk_frame_new(_("Cube analysis"));
     gtk_container_set_border_width(GTK_CONTAINER(pwFrame), 8);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pw = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
     pw = gtk_vbox_new(FALSE, 0);
+#endif
     gtk_container_add(GTK_CONTAINER(pwFrame), pw);
 
     pwTable = gtk_table_new(8, 4, FALSE);
@@ -813,14 +817,12 @@ CubeAnalysisCmark(GtkWidget * pw, cubehintdata * pchd)
 static GtkWidget *
 CreateCubeAnalysisTools(cubehintdata * pchd)
 {
-
-
     GtkWidget *pwTools;
     GtkWidget *pwEval = gtk_button_new_with_label(_("Eval"));
     GtkWidget *pwply;
     GtkWidget *pwEvalSettings = gtk_button_new_with_label(_("..."));
     GtkWidget *pwRollout = gtk_button_new_with_label(_("Rollout"));
-    GtkWidget *pwRolloutPresets = gtk_hbox_new(FALSE, 0);
+    GtkWidget *pwRolloutPresets;
     GtkWidget *pwRolloutSettings = gtk_button_new_with_label(_("..."));
     GtkWidget *pwMWC = gtk_toggle_button_new_with_label(_("MWC"));
     GtkWidget *pwCopy = gtk_button_new_with_label(_("Copy"));
@@ -830,6 +832,17 @@ CreateCubeAnalysisTools(cubehintdata * pchd)
     int i;
     char *sz;
 
+#if GTK_CHECK_VERSION(3,0,0)
+    gtk_style_context_add_class(gtk_widget_get_style_context(pwEval), "gnubg-analysis-button");
+    gtk_style_context_add_class(gtk_widget_get_style_context(pwEvalSettings), "gnubg-analysis-button");
+    gtk_style_context_add_class(gtk_widget_get_style_context(pwRollout), "gnubg-analysis-button");
+    gtk_style_context_add_class(gtk_widget_get_style_context(pwRolloutSettings), "gnubg-analysis-button");
+    gtk_style_context_add_class(gtk_widget_get_style_context(pwMWC), "gnubg-analysis-button");
+    gtk_style_context_add_class(gtk_widget_get_style_context(pwCopy), "gnubg-analysis-button");
+    gtk_style_context_add_class(gtk_widget_get_style_context(pwTempMap), "gnubg-analysis-button");
+    gtk_style_context_add_class(gtk_widget_get_style_context(pwCmark), "gnubg-analysis-button");
+#endif
+
     /* toolbox on the left with buttons for eval, rollout and more */
 
     pchd->pwTools = pwTools = gtk_table_new(2, 5, FALSE);
@@ -840,14 +853,20 @@ CreateCubeAnalysisTools(cubehintdata * pchd)
     gtk_table_attach(GTK_TABLE(pwTools), pwEvalSettings, 1, 2, 0, 1,
                      (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pw = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     pw = gtk_hbox_new(FALSE, 0);
+#endif
     gtk_table_attach(GTK_TABLE(pwTools), pw, 2, 3, 0, 1, (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
     for (i = 0; i < 5; ++i) {
 
         sz = g_strdup_printf("%d", i);  /* string is freed by set_data_full */
         pwply = gtk_button_new_with_label(sz);
-
+#if GTK_CHECK_VERSION(3,0,0)
+        gtk_style_context_add_class(gtk_widget_get_style_context(pwply), "gnubg-analysis-button");
+#endif
         gtk_box_pack_start(GTK_BOX(pw), pwply, TRUE, TRUE, 0);
 
         g_signal_connect(G_OBJECT(pwply), "clicked", G_CALLBACK(CubeAnalysisEvalPly), pchd);
@@ -860,6 +879,12 @@ CreateCubeAnalysisTools(cubehintdata * pchd)
 
     }
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwRolloutPresets = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
+    pwRolloutPresets = gtk_hbox_new(FALSE, 0);
+#endif
+
     gtk_table_attach(GTK_TABLE(pwTools), pwMWC, 3, 4, 0, 1,
                      (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
@@ -883,7 +908,9 @@ CreateCubeAnalysisTools(cubehintdata * pchd)
         GtkWidget *ro_preset;
         sz = g_strdup_printf("%c", i + 'a');    /* string is freed by set_data_full */
         ro_preset = gtk_button_new_with_label(sz);
-
+#if GTK_CHECK_VERSION(3,0,0)
+        gtk_style_context_add_class(gtk_widget_get_style_context(ro_preset), "gnubg-analysis-button");
+#endif
         gtk_box_pack_start(GTK_BOX(pwRolloutPresets), ro_preset, TRUE, TRUE, 0);
 
         g_signal_connect(G_OBJECT(ro_preset), "clicked", G_CALLBACK(CubeRolloutPresets), pchd);
@@ -950,7 +977,13 @@ CreateCubeAnalysis(moverecord * pmr, const matchstate * pms, int did_double, int
     pchd->did_double = did_double;
     pchd->did_take = did_take;
     pchd->hist = hist;
+
+#if GTK_CHECK_VERSION(3,0,0)
+    pchd->pw = pw = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 2);
+#else
     pchd->pw = pw = gtk_hbox_new(FALSE, 2);
+#endif
+
     switch (pmr->mt) {
 
     case MOVE_NORMAL:
@@ -980,16 +1013,26 @@ CreateCubeAnalysis(moverecord * pmr, const matchstate * pms, int did_double, int
 
     }
 
-    if (!pchd->pwFrame)
+    if (!pchd->pwFrame) {
+        g_free(pchd);
         return NULL;
+    }
 
     gtk_box_pack_start(GTK_BOX(pw), pchd->pwFrame, FALSE, FALSE, 0);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwx = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
     pwx = gtk_vbox_new(FALSE, 0);
+#endif
 
     gtk_box_pack_start(GTK_BOX(pwx), pw, FALSE, FALSE, 0);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwhb = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     pwhb = gtk_hbox_new(FALSE, 0);
+#endif
     gtk_box_pack_start(GTK_BOX(pwhb), CreateCubeAnalysisTools(pchd), FALSE, FALSE, 8);
 
     gtk_box_pack_start(GTK_BOX(pwx), pwhb, FALSE, FALSE, 0);
