@@ -16,15 +16,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkexport.h,v 1.2 2007/07/02 12:43:39 ace Exp $
+ * $Id: gtkexport.h,v 1.4 2013/06/16 02:16:14 mdpetch Exp $
  */
 
-#ifndef _GTKEXPORT_H_
-#define _GTKEXPORT_H_
+#ifndef GTKEXPORT_H
+#define GTKEXPORT_H
 
 #include "export.h"
 
 extern void
-GTKShowExport ( exportsetup *pexs );
+ GTKShowExport(exportsetup * pexs);
 
 #endif
