@@ -16,27 +16,22 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkmovefilter.h,v 1.3 2007/07/02 12:43:39 ace Exp $
+ * $Id: gtkmovefilter.h,v 1.7 2013/06/16 02:16:15 mdpetch Exp $
  */
 
-#ifndef _GTKMOVEFILTER_H_
-#define _GTKMOVEFILTER_H_
+#ifndef GTKMOVEFILTER_H
+#define GTKMOVEFILTER_H
 
-extern GtkWidget *
-MoveFilterWidget ( movefilter *pmf, 
-                   int *pfOK,
-                   GtkSignalFunc pfChanged, gpointer userdata );
+extern GtkWidget *MoveFilterWidget(movefilter * pmf, int *pfOK, GCallback pfChanged, gpointer userdata);
 
 extern void
-SetMovefilterCommands ( const char *sz,
-                  movefilter aamfNew[ MAX_FILTER_PLIES ][ MAX_FILTER_PLIES ], 
-                  movefilter aamfOld[ MAX_FILTER_PLIES ][ MAX_FILTER_PLIES ] );
+
+
+SetMovefilterCommands(const char *sz,
+                      movefilter aamfNew[MAX_FILTER_PLIES][MAX_FILTER_PLIES],
+                      movefilter aamfOld[MAX_FILTER_PLIES][MAX_FILTER_PLIES]);
 
 extern void
-MoveFilterOK ( GtkWidget *pw, GtkWidget *pwMoveFilter );
+ MoveFilterSetPredefined(GtkWidget * pwMoveFilter, const int i);
 
-extern void
-MoveFilterSetPredefined ( GtkWidget *pwMoveFilter, 
-                          const int i );
-
-#endif /* _GTKMOVEFILTER_H_ */
+#endif                          /* GTKMOVEFILTER_H */
