@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkmovelist.c,v 1.34 2013/06/16 02:16:15 mdpetch Exp $
+ * $Id: gtkmovelist.c,v 1.35 2016/05/07 21:16:48 plm Exp $
  */
 
 #include "config.h"
@@ -216,7 +216,7 @@ MoveListUpdate(const hintdata * phd)
     for (i = 0; i < pml->cMoves; i++) {
         float *ar = pml->amMoves[i].arEvalMove;
         int rankKnown;
-        char *highlight_sz;
+        const char *highlight_sz;
 
         if (showWLTree)
             gtk_list_store_set(store, &iter, 0, pml->amMoves + i, -1);
@@ -247,7 +247,7 @@ MoveListUpdate(const hintdata * phd)
         highlight_sz = (phd->piHighlight && *phd->piHighlight == i) ? "*" : "";
 
         if (rankKnown)
-            sprintf(sz, "%s%s%d", pml->amMoves[i].cmark ? "+" : "", highlight_sz, i + 1);
+            sprintf(sz, "%s%s%u", pml->amMoves[i].cmark ? "+" : "", highlight_sz, i + 1);
         else
             sprintf(sz, "%s%s??", pml->amMoves[i].cmark ? "+" : "", highlight_sz);
 
