@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkmovelistctrl.c,v 1.25 2014/07/20 21:03:22 plm Exp $
+ * $Id: gtkmovelistctrl.c,v 1.29 2017/11/09 22:18:34 plm Exp $
  */
 
 #include "config.h"
@@ -40,15 +40,25 @@ static void custom_cell_renderer_movelist_finalize(GObject * gobject);
 /* These functions are the heart of our custom cell renderer: */
 static void custom_cell_renderer_movelist_get_size(GtkCellRenderer * cell,
                                                    GtkWidget * widget,
-                                                   GdkRectangle * cell_area,
+                                                   gtk_locdef_cell_area * cell_area,
                                                    gint * x_offset, gint * y_offset, gint * width, gint * height);
 
 static void custom_cell_renderer_movelist_render(GtkCellRenderer * cell,
-                                                 GdkWindow * window,
+                                                 cairo_t * cr,
                                                  GtkWidget * widget,
-                                                 GdkRectangle * background_area,
-                                                 GdkRectangle * cell_area,
-                                                 GdkRectangle * expose_area, GtkCellRendererState flags);
+                                                 const GdkRectangle * background_area,
+                                                 const GdkRectangle * cell_area,
+                                                 GtkCellRendererState flags);
+
+#if ! GTK_CHECK_VERSION(3,0,0)
+static void custom_cell_renderer_movelist_render_window(GtkCellRenderer * cell,
+                                                        GdkWindow * window,
+                                                        GtkWidget * widget,
+                                                        GdkRectangle * background_area,
+                                                        GdkRectangle * cell_area,
+                                                        GdkRectangle * expose_area, GtkCellRendererState flags);
+#endif
+
 static gpointer parent_class;
 
 /***************************************************************************
@@ -136,7 +146,11 @@ custom_cell_renderer_movelist_class_init(CustomCellRendererMovelistClass * klass
     /* Override the two crucial functions that are the heart
      *   of a cell renderer in the parent class */
     cell_class->get_size = custom_cell_renderer_movelist_get_size;
+#if GTK_CHECK_VERSION(3,0,0)
     cell_class->render = custom_cell_renderer_movelist_render;
+#else
+    cell_class->render = custom_cell_renderer_movelist_render_window;
+#endif
 
     /* Install our very own properties */
     g_object_class_install_property(object_class, 1,
@@ -236,7 +250,7 @@ static int _s_A, _s_A2, _s_B, _s_C, _s_D, _s_E, _s_Y, _s_Z, _s_ZP, _s_a, _s_b, _
 static void
 custom_cell_renderer_movelist_get_size(GtkCellRenderer * cell,
                                        GtkWidget * widget,
-                                       GdkRectangle * cell_area,
+                                       gtk_locdef_cell_area * cell_area,
                                        gint * x_offset, gint * y_offset, gint * width, gint * height)
 {
     gint calc_width;
@@ -251,6 +265,8 @@ custom_cell_renderer_movelist_get_size(GtkCellRenderer * cell,
         PangoLayout *layout;
         char buf[100];
 
+        g_assert(fOutputDigits <= MAX_OUTPUT_DIGITS);
+
         sprintf(buf, "%.*f", fOutputDigits, 0.888888);
         layout = gtk_widget_create_pango_layout(widget, buf);
         pango_layout_get_pixel_extents(layout, NULL, &logical_rect);
@@ -261,7 +277,7 @@ custom_cell_renderer_movelist_get_size(GtkCellRenderer * cell,
 
         _s_Z = logical_rect.width;
 
-        sprintf(buf, "%.*f%%", fOutputDigits > 1 ? fOutputDigits - 1 : 0, 0.888888);
+        sprintf(buf, "%.*f%%", fOutputDigits > 1 ? MIN(fOutputDigits, MAX_OUTPUT_DIGITS) - 1 : 0, 0.888888);
         layout = gtk_widget_create_pango_layout(widget, buf);
         pango_layout_get_pixel_extents(layout, NULL, &logical_rect);
         g_object_unref(layout);
@@ -297,7 +313,7 @@ custom_cell_renderer_movelist_get_size(GtkCellRenderer * cell,
         pango_layout_get_pixel_extents(layout, NULL, &logical_rect);
         g_object_unref(layout);
         _s_c = logical_rect.width;
-        sprintf(buf, "0%.*f%%", fOutputDigits > 1 ? fOutputDigits - 1 : 0, 0.888888);
+        sprintf(buf, "0%.*f%%", fOutputDigits > 1 ? MIN(fOutputDigits, MAX_OUTPUT_DIGITS) - 1 : 0, 0.888888);
         layout = gtk_widget_create_pango_layout(widget, buf);
         pango_layout_get_pixel_extents(layout, NULL, &logical_rect);
         g_object_unref(layout);
@@ -344,46 +360,45 @@ custom_cell_renderer_movelist_get_size(GtkCellRenderer * cell,
 
 static void
 custom_cell_renderer_movelist_render(GtkCellRenderer * cell,
-                                     GdkWindow * window,
+                                     cairo_t * cr,
                                      GtkWidget * widget,
-                                     GdkRectangle * background_area,
-                                     GdkRectangle * cell_area, GdkRectangle * expose_area, GtkCellRendererState flags)
+                                     const GdkRectangle * background_area,
+                                     const GdkRectangle * cell_area,
+                                     GtkCellRendererState flags)
 {
     CustomCellRendererMovelist *cellprogress = CUSTOM_CELL_RENDERER_MOVELIST(cell);
     PangoLayout *layout = gtk_widget_create_pango_layout(widget, NULL);
-    GdkGC *gc;
     hintdata *phd = g_object_get_data(G_OBJECT(widget), "hintdata");
     int i, x, y, selected;
     char buf[100];
     float *ar;
-    GdkColor *pFontCol, *fg;
+    GdkColor *pFontCol;
     PangoRectangle logical_rect;
-    char *cmark_sz;
-    char *highlight_sz;
+    const char *cmark_sz;
+    const char *highlight_sz;
     cubeinfo ci;
     GetMatchStateCubeInfo(&ci, &ms);
     /*lint --e(641) */
     selected = (flags & GTK_CELL_RENDERER_SELECTED) && gtk_widget_has_focus(widget);
 
-    gc = gdk_gc_new(window);
-    if (expose_area)
-        gdk_gc_set_clip_rectangle(gc, expose_area);
-
     if (phd->piHighlight && cellprogress->rank - 1 == *phd->piHighlight)
         pFontCol = &psHighlight->fg[GTK_STATE_SELECTED];
     else
         pFontCol = NULL;
 
     if (!(flags & GTK_CELL_RENDERER_SELECTED)) {
-        gdk_gc_set_rgb_fg_color(gc, &gtk_widget_get_style(widget)->base[GTK_STATE_NORMAL]);
-        gdk_draw_rectangle(window, gc, TRUE, background_area->x, background_area->y,
-                           background_area->width, background_area->height);
-        gdk_gc_set_rgb_fg_color(gc, &gtk_widget_get_style(widget)->fg[GTK_STATE_NORMAL]);
+        gdk_cairo_set_source_color(cr, &gtk_widget_get_style(widget)->base[GTK_STATE_NORMAL]);
+        cairo_rectangle(cr, background_area->x, background_area->y, background_area->width, background_area->height);
+        cairo_fill(cr);
+        gdk_cairo_set_source_color(cr, &gtk_widget_get_style(widget)->fg[GTK_STATE_NORMAL]);
     } else {                    /* Draw text in reverse colours for highlight cell */
         if (!pFontCol && selected)
             pFontCol = &gtk_widget_get_style(widget)->base[GTK_STATE_NORMAL];
     }
 
+    if (pFontCol)
+        gdk_cairo_set_source_color(cr, pFontCol);
+
     /* First line of control */
     cmark_sz = cellprogress->pml->cmark ? "+" : "";
     highlight_sz = (phd->piHighlight && cellprogress->rank - 1 == *phd->piHighlight) ? "*" : "";
@@ -398,16 +413,19 @@ custom_cell_renderer_movelist_render(GtkCellRenderer * cell,
     x = _s_A + _s_a - logical_rect.width;
     y = _s_B;
 
-    gdk_draw_layout_with_colors(window, gc, cell_area->x + x, cell_area->y + y, layout, pFontCol, 0);
+    cairo_move_to(cr, cell_area->x + x, cell_area->y + y);
+    pango_cairo_show_layout(cr, layout);
 
     x = _s_A + _s_a + _s_Y * 3;
     (void) FormatEval(buf, &cellprogress->pml->esMove);
     pango_layout_set_text(layout, buf, -1);
-    gdk_draw_layout_with_colors(window, gc, cell_area->x + x, cell_area->y + y, layout, pFontCol, 0);
+    cairo_move_to(cr, cell_area->x + x, cell_area->y + y);
+    pango_cairo_show_layout(cr, layout);
 
     x += _s_b + _s_Y;
     pango_layout_set_text(layout, OutputEquity(cellprogress->pml->rScore, &ci, TRUE), -1);
-    gdk_draw_layout_with_colors(window, gc, cell_area->x + x, cell_area->y + y, layout, pFontCol, 0);
+    cairo_move_to(cr, cell_area->x + x, cell_area->y + y);
+    pango_cairo_show_layout(cr, layout);
 
     if (fOutputMWC)
         x += _s_cP + _s_Y * 2;
@@ -415,7 +433,8 @@ custom_cell_renderer_movelist_render(GtkCellRenderer * cell,
         x += _s_c + _s_Y * 2;
     if (cellprogress->rank != 1) {
         pango_layout_set_text(layout, OutputEquityDiff(cellprogress->pml->rScore, rBest, &ci), -1);
-        gdk_draw_layout_with_colors(window, gc, cell_area->x + x, cell_area->y + y, layout, pFontCol, 0);
+        cairo_move_to(cr, cell_area->x + x, cell_area->y + y);
+        pango_cairo_show_layout(cr, layout);
     }
 
     if (fOutputMWC)
@@ -429,7 +448,8 @@ custom_cell_renderer_movelist_render(GtkCellRenderer * cell,
         pango_layout_set_font_description(layout, pfd);
 
         pango_layout_set_text(layout, FormatMove(buf, msBoard(), cellprogress->pml->anMove), -1);
-        gdk_draw_layout_with_colors(window, gc, cell_area->x + x, cell_area->y + y, layout, pFontCol, 0);
+        cairo_move_to(cr, cell_area->x + x, cell_area->y + y);
+        pango_cairo_show_layout(cr, layout);
 
         pango_font_description_set_weight(pfd, PANGO_WEIGHT_NORMAL);
         pango_layout_set_font_description(layout, pfd);
@@ -443,9 +463,9 @@ custom_cell_renderer_movelist_render(GtkCellRenderer * cell,
     ar = cellprogress->pml->arEvalMove;
 
     if (selected)
-        fg = &gtk_widget_get_style(widget)->base[GTK_STATE_NORMAL];
+        gdk_cairo_set_source_color(cr, &gtk_widget_get_style(widget)->base[GTK_STATE_NORMAL]);
     else
-        fg = &wlCol;
+        gdk_cairo_set_source_color(cr, &wlCol);
 
     for (i = 0; i < 6; i++) {
         char *str;
@@ -460,7 +480,8 @@ custom_cell_renderer_movelist_render(GtkCellRenderer * cell,
             str++;
 
         pango_layout_set_text(layout, str, -1);
-        gdk_draw_layout_with_colors(window, gc, cell_area->x + x, cell_area->y + y, layout, fg, 0);
+        cairo_move_to(cr, cell_area->x + x, cell_area->y + y);
+        pango_cairo_show_layout(cr, layout);
 
         if (fOutputWinPC)
             x += _s_ZP;
@@ -472,7 +493,8 @@ custom_cell_renderer_movelist_render(GtkCellRenderer * cell,
             if (fOutputWinPC)
                 minOff -= _s_Y;
             pango_layout_set_text(layout, "-", -1);
-            gdk_draw_layout_with_colors(window, gc, cell_area->x + x + minOff, cell_area->y + y, layout, fg, 0);
+            cairo_move_to(cr, cell_area->x + x + minOff, cell_area->y + y);
+            pango_cairo_show_layout(cr, layout);
 
             x += _s_s;
         } else
@@ -480,8 +502,26 @@ custom_cell_renderer_movelist_render(GtkCellRenderer * cell,
     }
 
     g_object_unref(layout);
-
-    if (expose_area)
-        gdk_gc_set_clip_rectangle(gc, NULL);
-    g_object_unref(gc);
 }
+
+#if ! GTK_CHECK_VERSION(3,0,0)
+static void
+custom_cell_renderer_movelist_render_window(GtkCellRenderer * cell,
+                                            GdkWindow * window,
+                                            GtkWidget * widget,
+                                            GdkRectangle * background_area,
+                                            GdkRectangle * cell_area,
+                                            GdkRectangle * expose_area, GtkCellRendererState flags)
+{
+    cairo_t *cr;
+
+    cr = gdk_cairo_create(window);
+    if (expose_area) {
+        cairo_rectangle(cr, expose_area->x, expose_area->y, expose_area->width, expose_area->height);
+        cairo_clip(cr);
+    }
+
+    custom_cell_renderer_movelist_render(cell, cr, widget, background_area, cell_area, flags);
+    cairo_destroy(cr);
+}
+#endif
