@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkoptions.c,v 1.119 2016/01/31 12:56:01 plm Exp $
+ * $Id: gtkoptions.c,v 1.121 2017/11/01 09:06:24 plm Exp $
  */
 
 #include "config.h"
@@ -792,7 +792,7 @@ append_match_options(optionswidget * pow)
     pow->padjLength = GTK_ADJUSTMENT(gtk_adjustment_new(nDefaultLength, 0, 99, 1, 1, 0));
     pw = gtk_spin_button_new(GTK_ADJUSTMENT(pow->padjLength), 1, 0);
     gtk_box_pack_start(GTK_BOX(pwhbox), pw, TRUE, TRUE, 0);
-    gtk_box_pack_start(GTK_BOX(pwhbox), gtk_label_new(_("length|points")), FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(pwhbox), gtk_label_new(Q_("length|points")), FALSE, FALSE, 0);
     gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(pw), TRUE);
     gtk_widget_set_tooltip_text(pwev, _("Specify the default length to use when starting " "new matches."));
 
@@ -1081,7 +1081,7 @@ append_dice_options(optionswidget * pow)
                                   "how to double aggressively after a good opening "
                                   "sequence, (b) learn to control your temper "
                                   "while things are going bad, (c) learn to play "
-                                  "very good or very bad rolls, or (d) just have fun. "));
+                                  "very good or very bad rolls, or (d) just have fun."));
 
     pow->pwHigherDieFirst = gtk_check_button_new_with_label(_("Show higher die on left"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pow->pwHigherDieFirst), fGUIHighDieFirst);
