@@ -18,7 +18,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkpanels.c,v 1.79 2015/02/08 13:05:17 plm Exp $
+ * $Id: gtkpanels.c,v 1.84 2017/09/30 22:09:54 plm Exp $
  */
 
 #include "config.h"
@@ -32,7 +32,7 @@
 #include "gtkgame.h"
 #include "gtktoolbar.h"
 #include "positionid.h"
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
 #include "fun3d.h"
 #endif
 
@@ -174,7 +174,7 @@ extern gboolean
 ShowGameWindow(void)
 {
     ShowPanel(WINDOW_GAME);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/GameRecord")),
                                    TRUE);
@@ -188,7 +188,7 @@ ShowGameWindow(void)
 static gboolean
 ShowAnnotation(void)
 {
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/Commentary")),
                                    TRUE);
@@ -208,7 +208,7 @@ static gboolean
 ShowMessage(void)
 {
     ShowPanel(WINDOW_MESSAGE);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/Message")),
                                    TRUE);
@@ -222,7 +222,7 @@ static gboolean
 ShowAnalysis(void)
 {
     ShowPanel(WINDOW_ANALYSIS);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/Analysis")),
                                    TRUE);
@@ -238,7 +238,7 @@ static gboolean
 ShowTheoryWindow(void)
 {
     ShowPanel(WINDOW_THEORY);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/Theory")),
                                    TRUE);
@@ -252,7 +252,7 @@ static gboolean
 ShowCommandWindow(void)
 {
     ShowPanel(WINDOW_COMMAND);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/Command")),
                                    TRUE);
@@ -387,7 +387,7 @@ CreateTheoryWindow(void)
 
     store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING, -1);
     gtk_list_store_append(store, &iter);
-    gtk_list_store_set(store, &iter, 0, _("Pip_Count"), 1, "", -1);
+    gtk_list_store_set(store, &iter, 0, _("Pip count"), 1, "", -1);
     gtk_list_store_append(store, &iter);
     gtk_list_store_set(store, &iter, 0, _("EPC"), 1, "", -1);
     gtk_list_store_append(store, &iter);
@@ -617,10 +617,14 @@ CommandFocusIn(GtkWidget * UNUSED(widget), GdkEventFocus * UNUSED(eventDetails),
 static GtkWidget *
 CreateCommandWindow(void)
 {
-    GtkWidget *pwhbox;
-    GtkWidget *pwvbox = gtk_vbox_new(FALSE, 0);
+    GtkWidget *pwhbox, *pwvbox;
     GtkWidget *pwShowHelp;
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwvbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
+    pwvbox = gtk_vbox_new(FALSE, 0);
+#endif
     CreatePanel(WINDOW_COMMAND, pwvbox, _("GNU Backgammon - Command"), "command");
 
     cedPanel.cmdString = NULL;
@@ -636,7 +640,11 @@ CreateCommandWindow(void)
     g_signal_connect(G_OBJECT(cedPanel.pwEntry), "key-press-event", G_CALLBACK(CommandKeyPress), &cedPanel);
     g_signal_connect(G_OBJECT(cedPanel.pwEntry), "activate", G_CALLBACK(CommandOK), &cedPanel);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwhbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     pwhbox = gtk_hbox_new(FALSE, 0);
+#endif
     gtk_box_pack_start(GTK_BOX(pwvbox), pwhbox, FALSE, FALSE, 0);
 
     gtk_box_pack_start(GTK_BOX(pwhbox), cedPanel.cmdEntryCombo, TRUE, TRUE, 10);
@@ -671,11 +679,24 @@ CreateAnalysisWindow(void)
         gtk_window_add_accel_group(GTK_WINDOW(woPanel[WINDOW_ANALYSIS].pwWin), pagMain);
 
         gtk_paned_pack1(GTK_PANED(pwPaned), pwAnalysis = gtk_label_new(NULL), TRUE, FALSE);
-        gtk_paned_pack2(GTK_PANED(pwPaned), pHbox = gtk_hbox_new(FALSE, 0), FALSE, TRUE);
+#if GTK_CHECK_VERSION(3,0,0)
+        pHbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
+        pHbox = gtk_hbox_new(FALSE, 0);
+#endif
+        gtk_paned_pack2(GTK_PANED(pwPaned), pHbox, FALSE, TRUE);
     } else {
+#if GTK_CHECK_VERSION(3,0,0)
+        pHbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
         pHbox = gtk_hbox_new(FALSE, 0);
+#endif
         gtk_box_pack_start(GTK_BOX(pHbox), pwAnalysis = gtk_label_new(NULL), TRUE, TRUE, 0);
+#if GTK_CHECK_VERSION(3,0,0)
+        pHbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
         pHbox = gtk_hbox_new(FALSE, 0);
+#endif
     }
 
     pwCommentary = gtk_text_view_new();
@@ -743,13 +764,13 @@ GTKAddGame(moverecord * pmr)
 extern void
 GTKRegenerateGames(void)
 {
-    listOLD *pl, *plGame;
+    listOLD *pl;
     int i = gtk_combo_box_get_active(GTK_COMBO_BOX(game_select_combo));
 
     GL_SetNames();
     GTKPopGame(0);
     for (pl = lMatch.plNext; pl->p; pl = pl->plNext) {
-        plGame = pl->p;
+        listOLD *plGame = pl->p;
         GTKAddGame(plGame->plNext->p);
     }
 
@@ -785,9 +806,17 @@ SelectGame(GtkWidget * pw, void *UNUSED(data))
 static void
 CreateGameWindow(void)
 {
+    GtkWidget *psw = gtk_scrolled_window_new(NULL, NULL);
+    GtkWidget *pvbox, *phbox;
 
-    GtkWidget *psw = gtk_scrolled_window_new(NULL, NULL),
-        *pvbox = gtk_vbox_new(FALSE, 0), *phbox = gtk_hbox_new(FALSE, 0);
+#if GTK_CHECK_VERSION(3,0,0)
+    g_object_set(G_OBJECT(psw), "expand", TRUE, NULL);
+    pvbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+    phbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
+    pvbox = gtk_vbox_new(FALSE, 0);
+    phbox = gtk_hbox_new(FALSE, 0);
+#endif
 
     if (!woPanel[WINDOW_GAME].docked) {
         woPanel[WINDOW_GAME].pwWin = gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -810,6 +839,7 @@ CreateGameWindow(void)
     gtk_container_add(GTK_CONTAINER(pvbox), psw);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(psw), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
 
+    gtk_widget_set_size_request(psw, -1, 150);
     gtk_container_add(GTK_CONTAINER(psw), GL_Create());
 
     if (!woPanel[WINDOW_GAME].docked) {
@@ -823,9 +853,17 @@ static void
 CreateHeadWindow(gnubgwindow panel, const char *sz, GtkWidget * pwWidge)
 {
     GtkWidget *pwLab = gtk_label_new(sz);
-    GtkWidget *pwVbox = gtk_vbox_new(FALSE, 0);
-    GtkWidget *pwHbox = gtk_hbox_new(FALSE, 0);
+    GtkWidget *pwVbox, *pwHbox;
     GtkWidget *pwX = gtk_button_new();
+
+#if GTK_CHECK_VERSION(3,0,0)
+    pwVbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+    pwHbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
+    pwVbox = gtk_vbox_new(FALSE, 0);
+    pwHbox = gtk_hbox_new(FALSE, 0);
+#endif
+
     gtk_button_set_image(GTK_BUTTON(pwX), gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU));
     g_signal_connect(G_OBJECT(pwX), "clicked", G_CALLBACK(woPanel[panel].hideFun), NULL);
 
@@ -862,7 +900,7 @@ static gboolean
 DeleteMessage(void)
 {
     HidePanel(WINDOW_MESSAGE);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/Message")),
                                    FALSE);
@@ -877,7 +915,7 @@ static gboolean
 DeleteAnalysis(void)
 {
     HidePanel(WINDOW_ANALYSIS);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/Analysis")),
                                    FALSE);
@@ -892,7 +930,7 @@ static gboolean
 DeleteAnnotation(void)
 {
     HidePanel(WINDOW_ANNOTATION);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/Commentary")),
                                    FALSE);
@@ -907,7 +945,7 @@ static gboolean
 DeleteGame(void)
 {
     HidePanel(WINDOW_GAME);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/GameRecord")),
                                    FALSE);
@@ -922,7 +960,7 @@ static gboolean
 DeleteTheoryWindow(void)
 {
     HidePanel(WINDOW_THEORY);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/Theory")),
                                    FALSE);
@@ -936,7 +974,7 @@ static gboolean
 DeleteCommandWindow(void)
 {
     HidePanel(WINDOW_COMMAND);
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/PanelsMenu/Command")),
                                    FALSE);
@@ -1043,7 +1081,7 @@ DockPanels(void)
     if (fDockPanels) {
         RefreshGeometries();    /* Get the current window positions */
 
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
         gtk_widget_show((gtk_ui_manager_get_widget(puim, "/MainMenu/ViewMenu/PanelsMenu/Commentary")));
 
         if (fDisplayPanels) {
@@ -1078,7 +1116,7 @@ DockPanels(void)
         if (fDisplayPanels)
             SwapBoardToPanel(FALSE, TRUE);
 
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
         gtk_widget_hide((gtk_ui_manager_get_widget(puim, "/MainMenu/ViewMenu/PanelsMenu/Commentary")));
         gtk_widget_hide((gtk_ui_manager_get_widget(puim, "/MainMenu/ViewMenu/HidePanels")));
         gtk_widget_hide((gtk_ui_manager_get_widget(puim, "/MainMenu/ViewMenu/RestorePanels")));
@@ -1101,7 +1139,7 @@ DockPanels(void)
         CreateTheoryWindow();
         CreateCommandWindow();
     }
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget(puim,
                                                        "/MainMenu/ViewMenu/PanelsMenu/Message"), !fDockPanels
                              || fDisplayPanels);
@@ -1138,7 +1176,7 @@ DockPanels(void)
         GTKSetGame(currentSelectedGame);
 
     /* Make sure check item is correct */
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(gtk_ui_manager_get_widget(puim,
                                                                                  "/MainMenu/ViewMenu/DockPanels")),
                                    fDockPanels);
@@ -1160,7 +1198,7 @@ ShowAllPanels(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
         return;
 
     /* Hide for smoother appearance */
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
     if (display_is_3d(bd->rd))
         gtk_widget_hide(GetDrawingArea3d(bd->bd3d));
     else
@@ -1174,7 +1212,7 @@ ShowAllPanels(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
             woPanel[i].showFun();
     }
 
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_widget_show((gtk_ui_manager_get_widget(puim, "/MainMenu/ViewMenu/HidePanels")));
     gtk_widget_hide((gtk_ui_manager_get_widget(puim, "/MainMenu/ViewMenu/RestorePanels")));
     gtk_widget_set_sensitive(gtk_ui_manager_get_widget(puim, "/MainMenu/ViewMenu/PanelsMenu/Message"), TRUE);
@@ -1196,7 +1234,7 @@ ShowAllPanels(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
 #endif
     SwapBoardToPanel(TRUE, TRUE);
 
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
     if (display_is_3d(bd->rd))
         gtk_widget_show(GetDrawingArea3d(bd->bd3d));
     else
@@ -1214,7 +1252,7 @@ DoHideAllPanels(int updateEvents)
         return;
 
     /* Hide for smoother appearance */
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
     if (display_is_3d(bd->rd))
         gtk_widget_hide(GetDrawingArea3d(bd->bd3d));
     else
@@ -1230,7 +1268,7 @@ DoHideAllPanels(int updateEvents)
         }
     }
 
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
     gtk_widget_show((gtk_ui_manager_get_widget(puim, "/MainMenu/ViewMenu/RestorePanels")));
     gtk_widget_set_sensitive((gtk_ui_manager_get_widget(puim, "/MainMenu/ViewMenu/RestorePanels")), TRUE);
     gtk_widget_hide((gtk_ui_manager_get_widget(puim, "/MainMenu/ViewMenu/HidePanels")));
@@ -1258,7 +1296,7 @@ DoHideAllPanels(int updateEvents)
     /* Resize screen */
     SetMainWindowSize();
 
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
     if (display_is_3d(bd->rd))
         gtk_widget_show(GetDrawingArea3d(bd->bd3d));
     else
@@ -1272,7 +1310,7 @@ HideAllPanels(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
     DoHideAllPanels(TRUE);
 }
 
-#if (USE_GTKUIMANAGER)
+#if defined(USE_GTKUIMANAGER)
 void
 ToggleDockPanels(GtkToggleAction * action, gpointer UNUSED(user_data))
 {
@@ -1286,7 +1324,7 @@ ToggleDockPanels(GtkToggleAction * action, gpointer UNUSED(user_data))
 extern void
 ToggleDockPanels(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * pw)
 {
-    int newValue = GTK_CHECK_MENU_ITEM(pw)->active;
+    int newValue = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(pw));
     if (fDockPanels != newValue) {
         fDockPanels = newValue;
         DockPanels();
