@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkrace.c,v 1.41 2013/06/16 02:16:16 mdpetch Exp $
+ * $Id: gtkrace.c,v 1.45 2017/08/19 21:55:27 plm Exp $
  */
 
 #include "config.h"
@@ -46,6 +46,8 @@ typedef struct _racewidget {
     int fMove;
 } racewidget;
 
+static gint current_page_num = 0;
+
 static GtkWidget *
 monospace_text(const char *szOutput)
 {
@@ -89,6 +91,14 @@ KeithPage(TanBoard anBoard, const int UNUSED(fMove))
     return monospace_text(sz);
 }
 
+static GtkWidget *
+IsightPage(TanBoard anBoard, const int UNUSED(fMove))
+{
+    char sz[500];
+    show_isight(anBoard, sz);
+    return monospace_text(sz);
+}
+
 static GtkWidget *
 Pip8912Page(TanBoard anBoard, const int UNUSED(fMove))
 {
@@ -110,7 +120,8 @@ EffectivePipCount(const float arPips[2], const float arWastage[2], const int fIn
 {
 
     GtkWidget *pwTable = gtk_table_new(3, 4, FALSE);
-    GtkWidget *pwvbox = gtk_vbox_new(FALSE, 0);
+
+    GtkWidget *pwvbox;
     GtkWidget *pw;
     GtkWidget *pwFrame;
     gchar *sz;
@@ -118,6 +129,12 @@ EffectivePipCount(const float arPips[2], const float arWastage[2], const int fIn
 
     pwFrame = gtk_frame_new(_("Effective pip count"));
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwvbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
+    pwvbox = gtk_vbox_new(FALSE, 0);
+#endif
+
     gtk_container_add(GTK_CONTAINER(pwFrame), pwvbox);
     gtk_container_set_border_width(GTK_CONTAINER(pwvbox), 4);
 
@@ -243,17 +260,26 @@ static GtkWidget *
 OSRPage(TanBoard UNUSED(anBoard), racewidget * prw)
 {
 
-    GtkWidget *pwvbox = gtk_vbox_new(FALSE, 4);
+    GtkWidget *pwvbox;
     GtkWidget *pw;
     GtkWidget *pwp = gtk_alignment_new(0, 0, 0, 0);
     float ar0[2] = { 0, 0 };
     char *pch;
 
     gtk_container_set_border_width(GTK_CONTAINER(pwp), 4);
+#if GTK_CHECK_VERSION(3,0,0)
+    pwvbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
+#else
+    pwvbox = gtk_vbox_new(FALSE, 4);
+#endif
     gtk_container_add(GTK_CONTAINER(pwp), pwvbox);
 
     prw->padjTrials = GTK_ADJUSTMENT(gtk_adjustment_new(5760, 1, 1296 * 1296, 36, 36, 0));
+#if GTK_CHECK_VERSION(3,0,0)
+    pw = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     pw = gtk_hbox_new(FALSE, 0);
+#endif
     gtk_box_pack_start(GTK_BOX(pwvbox), pw, FALSE, FALSE, 4);
 
     gtk_box_pack_start(GTK_BOX(pw), gtk_label_new(_("Trials:")), FALSE, FALSE, 4);
@@ -264,7 +290,11 @@ OSRPage(TanBoard UNUSED(anBoard), racewidget * prw)
 
     /* separator */
 
+#if GTK_CHECK_VERSION(3,0,0)
+    gtk_box_pack_start(GTK_BOX(pwvbox), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), FALSE, FALSE, 4);
+#else
     gtk_box_pack_start(GTK_BOX(pwvbox), gtk_hseparator_new(), FALSE, FALSE, 4);
+#endif
 
     /* result */
 
@@ -278,7 +308,11 @@ OSRPage(TanBoard UNUSED(anBoard), racewidget * prw)
 
     /* effective pip count */
 
+#if GTK_CHECK_VERSION(3,0,0)
+    gtk_box_pack_start(GTK_BOX(pwvbox), gtk_separator_new(GTK_ORIENTATION_HORIZONTAL), FALSE, FALSE, 4);
+#else
     gtk_box_pack_start(GTK_BOX(pwvbox), gtk_hseparator_new(), FALSE, FALSE, 4);
+#endif
 
     gtk_box_pack_start(GTK_BOX(pwvbox), EffectivePipCount(ar0, ar0, !prw->fMove, &prw->epcwOSR), FALSE, FALSE, 4);
 
@@ -286,12 +320,16 @@ OSRPage(TanBoard UNUSED(anBoard), racewidget * prw)
 
 }
 
+static void
+set_current_page(GtkWidget * UNUSED(pw), gpointer UNUSED(page), guint page_num, gpointer * UNUSED(data))
+{
+    current_page_num = page_num;
+
+    return;
+}
+
 /*
- * Display widget with misc. race stuff:
- * - kleinman
- * - thorp
- * - one chequer race
- * - one sided rollout
+ * Display widget with various race metrics
  */
 
 extern void
@@ -336,6 +374,10 @@ GTKShowRace(TanBoard anBoard)
 
     gtk_notebook_append_page(GTK_NOTEBOOK(pwNotebook), KeithPage(anBoard, prw->fMove), gtk_label_new(_("Keith Count")));
 
+    /* Isight */
+
+    gtk_notebook_append_page(GTK_NOTEBOOK(pwNotebook), IsightPage(anBoard, prw->fMove), gtk_label_new(_("Isight Count")));
+
     /* One sided rollout */
 
     gtk_notebook_append_page(GTK_NOTEBOOK(pwNotebook),
@@ -345,13 +387,18 @@ GTKShowRace(TanBoard anBoard)
     gtk_notebook_append_page(GTK_NOTEBOOK(pwNotebook),
                              TwoSidedPage(anBoard, prw->fMove), gtk_label_new(_("Two-Sided Database")));
 
+    g_signal_connect_after(G_OBJECT(pwNotebook), "switch-page", G_CALLBACK(set_current_page), pwNotebook);
+
+    g_object_set_data_full(G_OBJECT(pwDialog), "racewidget", prw, free);
 
     /* show dialog */
 
     /* OSR can take a long time for non-race positions */
     if (ClassifyPosition(msBoard(), ms.bgv) <= CLASS_RACE)
         PerformOSR(NULL, prw);
-    gtk_notebook_set_current_page(GTK_NOTEBOOK(pwNotebook), 0);
+
+    gtk_widget_show_all(pwNotebook);
+    gtk_notebook_set_current_page(GTK_NOTEBOOK(pwNotebook), current_page_num);
 
     GTKRunDialog(pwDialog);
 }
