@@ -16,13 +16,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkrace.h,v 1.4 2007/12/12 23:08:17 Superfly_Jon Exp $
+ * $Id: gtkrace.h,v 1.6 2013/06/16 02:16:16 mdpetch Exp $
  */
 
-#ifndef _GTKRACE_H_
-#define _GTKRACE_H_
+#ifndef GTKRACE_H
+#define GTKRACE_H
 
 extern void
-GTKShowRace ( TanBoard anBoard );
+ GTKShowRace(TanBoard anBoard);
 
 #endif
