@@ -16,13 +16,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtkrolls.h,v 1.2 2007/07/02 12:43:39 ace Exp $
+ * $Id: gtkrolls.h,v 1.4 2013/06/16 02:16:16 mdpetch Exp $
  */
 
-#ifndef _GTKROLLS_H_
-#define _GTKROLLS_H_
+#ifndef GTKROLLS_H
+#define GTKROLLS_H
 
 extern void
-GTKShowRolls ( const gint nDepth, evalcontext *pec, matchstate *pms );
+ GTKShowRolls(const gint nDepth, evalcontext * pec, matchstate * pms);
 
-#endif /* _GTKROLLS_H_ */
+#endif                          /* GTKROLLS_H */
