@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtktheory.c,v 1.62 2016/05/11 21:33:08 plm Exp $
+ * $Id: gtktheory.c,v 1.67 2017/11/09 22:16:44 plm Exp $
  */
 
 #include "config.h"
@@ -86,7 +86,7 @@ typedef struct _theorywidget {
 
     /* radio buttons for plies */
 
-    GtkWidget *apwPly[MAXPLY];
+    GtkWidget *apwPly[MAXPLY+1];
 
 } theorywidget;
 
@@ -346,7 +346,7 @@ TheoryUpdated(GtkWidget * UNUSED(pw), theorywidget * ptw)
     /* set max on the gammon spinners */
 
     for (i = 0; i < 2; ++i)
-        gtk_adjustment_set_upper(ptw->aapwRates[i][1], 100.0f - gtk_adjustment_get_value(ptw->aapwRates[i][0]));
+        gtk_adjustment_set_upper(ptw->aapwRates[i][1], 100.0 - gtk_adjustment_get_value(ptw->aapwRates[i][0]));
 
     SetCubeInfo(&ci, ci.nCube, 0, 0, ci.nMatchTo, ci.anScore, ci.fCrawford, ci.fJacoby, ci.fBeavers, ci.bgv);
 
@@ -463,8 +463,8 @@ TheoryUpdated(GtkWidget * UNUSED(pw), theorywidget * ptw)
 
 }
 
-static void
-GraphExpose(GtkWidget * pwGraph, GdkEventExpose * UNUSED(pev), theorywidget * ptw)
+static gboolean
+GraphDraw(GtkWidget * pwGraph, cairo_t * cr, theorywidget * ptw)
 {
 
     GtkAllocation allocation;
@@ -472,6 +472,11 @@ GraphExpose(GtkWidget * pwGraph, GdkEventExpose * UNUSED(pev), theorywidget * pt
     char sz[4];
     PangoLayout *layout;
 
+#if ! GTK_CHECK_VERSION(3,0,0)
+    /* The gtk_locdef_* below don't use cr with GTK2. Avoid compiler warning inthis case. */
+    (void)cr;
+#endif
+
     gtk_widget_get_allocation(pwGraph, &allocation);
     x = 8;
     y = 12;
@@ -489,8 +494,8 @@ GraphExpose(GtkWidget * pwGraph, GdkEventExpose * UNUSED(pev), theorywidget * pt
     iPlayer = pwGraph == ptw->apwGraph[1];
 
     for (i = 0; i <= 20; i++) {
-        gtk_paint_vline(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph), GTK_STATE_NORMAL,
-                        NULL, pwGraph, "tick", y - 1, i & 3 ? y - 3 : y - 5, x + cx * i / 20);
+        gtk_locdef_paint_vline(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph), cr, GTK_STATE_NORMAL,
+                               NULL, pwGraph, "tick", y - 1, (i & 3) ? y - 3 : y - 5, x + cx * i / 20);
 
         if (!(i & 3)) {
             int width;
@@ -498,9 +503,9 @@ GraphExpose(GtkWidget * pwGraph, GdkEventExpose * UNUSED(pev), theorywidget * pt
             sprintf(sz, "%d", i * 5);
             pango_layout_set_text(layout, sz, -1);
             pango_layout_get_pixel_size(layout, &width, &height);
-            gtk_paint_layout(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph),
-                             GTK_STATE_NORMAL, TRUE, NULL, pwGraph, "label",
-                             x + cx * i / 20 - width / 2 /* FIXME */ , y - height - 1, layout);
+            gtk_locdef_paint_layout(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph), cr,
+                                    GTK_STATE_NORMAL, TRUE, NULL, pwGraph, "label",
+                                    x + cx * i / 20 - width / 2 /* FIXME */ , y - height - 1, layout);
         }
     }
     g_object_unref(layout);
@@ -508,23 +513,36 @@ GraphExpose(GtkWidget * pwGraph, GdkEventExpose * UNUSED(pev), theorywidget * pt
     for (i = 0; i < 3; i++)
         ax[i] = (int) (x + cx * ptw->aar[iPlayer][i]);
 
-    gtk_paint_box(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph), GTK_STATE_NORMAL,
-                  GTK_SHADOW_IN, NULL, pwGraph, "doubling-window", x, 12, cx, cy);
+    gtk_locdef_paint_box(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph), cr, GTK_STATE_NORMAL,
+                         GTK_SHADOW_IN, NULL, pwGraph, "doubling-window", x, 12, cx, cy);
 
     /* FIXME it's horrible to abuse the "state" parameters like this */
     if (ptw->aar[iPlayer][1] > ptw->aar[iPlayer][0])
-        gtk_paint_box(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph),
-                      GTK_STATE_ACTIVE, GTK_SHADOW_OUT, NULL, pwGraph, "take", ax[0], 13, ax[1] - ax[0], cy - 2);
+        gtk_locdef_paint_box(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph), cr,
+                             GTK_STATE_ACTIVE, GTK_SHADOW_OUT, NULL, pwGraph, "take", ax[0], 13, ax[1] - ax[0], cy - 2);
 
     if (ptw->aar[iPlayer][2] > ptw->aar[iPlayer][1])
-        gtk_paint_box(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph),
-                      GTK_STATE_PRELIGHT, GTK_SHADOW_OUT, NULL, pwGraph, "drop", ax[1], 13, ax[2] - ax[1], cy - 2);
+        gtk_locdef_paint_box(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph), cr,
+                             GTK_STATE_PRELIGHT, GTK_SHADOW_OUT, NULL, pwGraph, "drop", ax[1], 13, ax[2] - ax[1], cy - 2);
 
-    if (ptw->aar[iPlayer][2] < 1.0)
-        gtk_paint_box(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph),
-                      GTK_STATE_SELECTED, GTK_SHADOW_OUT, NULL, pwGraph, "too-good", ax[2], 13, x + cx - ax[2], cy - 2);
+    if (ptw->aar[iPlayer][2] < 1.0f)
+        gtk_locdef_paint_box(gtk_widget_get_style(pwGraph), gtk_widget_get_window(pwGraph), cr,
+                             GTK_STATE_SELECTED, GTK_SHADOW_OUT, NULL, pwGraph, "too-good", ax[2], 13, x + cx - ax[2], cy - 2);
+
+    return TRUE;
 }
 
+#if ! GTK_CHECK_VERSION(3,0,0)
+static void
+GraphExpose(GtkWidget * pwGraph, GdkEventExpose * UNUSED(pev), theorywidget * ptw)
+{
+    cairo_t *cr;
+
+    cr = gdk_cairo_create(gtk_widget_get_window(pwGraph));
+    GraphDraw(pwGraph, cr, ptw);
+    cairo_destroy(cr);
+}
+#endif
 
 static void
 PlyClicked(GtkWidget * pw, theorywidget * ptw)
@@ -591,8 +609,6 @@ GTKShowTheory(const int fActivePage)
 
     theorywidget *ptw;
 
-    ptw = malloc(sizeof(theorywidget));
-
     /* create dialog */
 
     pwDialog = GTKCreateDialog(_("GNU Backgammon - Theory"), DT_INFO,
@@ -600,17 +616,32 @@ GTKShowTheory(const int fActivePage)
 
     gtk_window_set_default_size(GTK_WINDOW(pwDialog), 660, 300);
 
+    ptw = malloc(sizeof(theorywidget));
+    g_object_set_data_full(G_OBJECT(pwDialog), "theorywidget", ptw, free);
+
+#if GTK_CHECK_VERSION(3,0,0)
+    pwOuterHBox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 8);
+#else
     pwOuterHBox = gtk_hbox_new(FALSE, 8);
+#endif
     gtk_container_set_border_width(GTK_CONTAINER(pwOuterHBox), 8);
 
     gtk_container_add(GTK_CONTAINER(DialogArea(pwDialog, DA_MAIN)), pwOuterHBox);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwVBox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
     pwVBox = gtk_vbox_new(FALSE, 0);
+#endif
     gtk_box_pack_start(GTK_BOX(pwOuterHBox), pwVBox, FALSE, FALSE, 0);
 
     /* match/money play */
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwHBox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     pwHBox = gtk_hbox_new(FALSE, 0);
+#endif
     gtk_box_pack_start(GTK_BOX(pwVBox), pwHBox, FALSE, FALSE, 0);
 
     gtk_container_add(GTK_CONTAINER(pwHBox), ptw->apwRadio[0] = gtk_radio_button_new_with_label(NULL, _("Match play")));
@@ -630,7 +661,11 @@ GTKShowTheory(const int fActivePage)
     ptw->apwFrame[0] = gtk_frame_new(_("Match score"));
     gtk_box_pack_start(GTK_BOX(pwVBox), ptw->apwFrame[0], FALSE, FALSE, 0);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pw = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
     pw = gtk_vbox_new(FALSE, 0);
+#endif
     gtk_container_add(GTK_CONTAINER(ptw->apwFrame[0]), pw);
 
     pwTable = gtk_table_new(2, 3, FALSE);
@@ -660,7 +695,11 @@ GTKShowTheory(const int fActivePage)
 
     }
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwHBox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     pwHBox = gtk_hbox_new(FALSE, 0);
+#endif
     gtk_container_add(GTK_CONTAINER(pw), pwHBox);
 
     gtk_container_add(GTK_CONTAINER(pwHBox), ptw->pwCrawford = gtk_check_button_new_with_label(_("Crawford game")));
@@ -670,7 +709,11 @@ GTKShowTheory(const int fActivePage)
     ptw->pwCubeFrame = gtk_frame_new(_("Cube"));
     gtk_container_add(GTK_CONTAINER(pw), ptw->pwCubeFrame);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwHBox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     pwHBox = gtk_hbox_new(FALSE, 0);
+#endif
     gtk_container_add(GTK_CONTAINER(ptw->pwCubeFrame), pwHBox);
 
     j = 1;
@@ -696,7 +739,11 @@ GTKShowTheory(const int fActivePage)
     pwFrame = gtk_frame_new(_("Match equity table"));
     gtk_container_add(GTK_CONTAINER(pw), pwFrame);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwx = gtk_box_new(GTK_ORIENTATION_VERTICAL, 4);
+#else
     pwx = gtk_vbox_new(FALSE, 4);
+#endif
     gtk_container_add(GTK_CONTAINER(pwFrame), pwx);
 
     gtk_box_pack_start(GTK_BOX(pwx), pwz = gtk_label_new((char *) miCurrent.szName), FALSE, FALSE, 0);
@@ -712,7 +759,11 @@ GTKShowTheory(const int fActivePage)
     ptw->apwFrame[1] = gtk_frame_new(_("Money play"));
     gtk_box_pack_start(GTK_BOX(pwVBox), ptw->apwFrame[1], FALSE, FALSE, 0);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwHBox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 0);
+#else
     pwHBox = gtk_hbox_new(FALSE, 0);
+#endif
     gtk_container_add(GTK_CONTAINER(ptw->apwFrame[1]), pwHBox);
 
     gtk_container_add(GTK_CONTAINER(pwHBox), ptw->pwJacoby = gtk_check_button_new_with_label(_("Jacoby rule")));
@@ -729,7 +780,11 @@ GTKShowTheory(const int fActivePage)
     pwFrame = gtk_frame_new(_("Gammon and backgammon percentages"));
     gtk_box_pack_start(GTK_BOX(pwVBox), pwFrame, FALSE, FALSE, 0);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwx = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
     pwx = gtk_vbox_new(FALSE, 0);
+#endif
     gtk_container_add(GTK_CONTAINER(pwFrame), pwx);
 
 
@@ -770,10 +825,14 @@ GTKShowTheory(const int fActivePage)
 
     /* radio buttons with plies */
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwz = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
+#else
     pwz = gtk_hbox_new(FALSE, 4);
+#endif
     gtk_box_pack_start(GTK_BOX(pwx), pwz, FALSE, FALSE, 4);
 
-    for (i = 0; i < MAXPLY; ++i) {
+    for (i = 0; i <= MAXPLY; ++i) {
 
         gchar *sz = g_strdup_printf(_("%d ply"), i);
         if (!i)
@@ -802,7 +861,11 @@ GTKShowTheory(const int fActivePage)
 
     /* market window */
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwVBox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 10);
+#else
     pwVBox = gtk_vbox_new(FALSE, 10);
+#endif
     gtk_notebook_append_page(GTK_NOTEBOOK(pwNotebook), pwVBox, gtk_label_new(_("Market window")));
 
     do_mw_views(ptw);
@@ -819,7 +882,11 @@ GTKShowTheory(const int fActivePage)
     }
 
     /* window graph */
+#if GTK_CHECK_VERSION(3,0,0)
+    pwVBox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
     pwVBox = gtk_vbox_new(FALSE, 0);
+#endif
     gtk_notebook_append_page(GTK_NOTEBOOK(pwNotebook), pwVBox, gtk_label_new(_("Window graph")));
 
     for (i = 0; i < 2; i++) {
@@ -832,12 +899,20 @@ GTKShowTheory(const int fActivePage)
         gtk_widget_set_name(ptw->apwGraph[i], "gnubg-doubling-window-graph");
         gtk_container_set_border_width(GTK_CONTAINER(pwAlign), 4);
         gtk_widget_set_size_request(ptw->apwGraph[i], -1, 48);
+#if GTK_CHECK_VERSION(3,0,0)
+        g_signal_connect(G_OBJECT(ptw->apwGraph[i]), "draw", G_CALLBACK(GraphDraw), ptw);
+#else
         g_signal_connect(G_OBJECT(ptw->apwGraph[i]), "expose_event", G_CALLBACK(GraphExpose), ptw);
+#endif
     }
 
     /* gammon prices */
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwVBox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
+#else
     pwVBox = gtk_vbox_new(FALSE, 0);
+#endif
 
     ptw->pwGammonPrice = gtk_text_view_new();
     gtk_text_view_set_editable(GTK_TEXT_VIEW(ptw->pwGammonPrice), FALSE);
