@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: gtktoolbar.c,v 1.74 2015/10/14 22:30:27 plm Exp $
+ * $Id: gtktoolbar.c,v 1.77 2017/08/26 18:51:22 plm Exp $
  */
 
 #include "config.h"
@@ -212,9 +212,8 @@ click_edit(void)
 {
     if (!inCallback) {
 #if defined(USE_GTKUIMANAGER)
-        gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(gtk_ui_manager_get_action(puim,
-                                                                                 "/MainMenu/EditMenu/EditPosition")),
-                                     TRUE);
+        GtkAction *editstatus = gtk_ui_manager_get_action(puim, "/MainMenu/EditMenu/EditPosition");
+        gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(editstatus), !gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(editstatus)));
 #else
         toolbarwidget *ptw = g_object_get_data(G_OBJECT(pwToolbar), "toolbarwidget");
         gtk_button_clicked(GTK_BUTTON(ptw->pwEdit));
@@ -336,9 +335,8 @@ ToolbarAddButton(GtkToolbar * pwToolbar, const char *stockID, const char *label,
 
     return GTK_WIDGET(but);
 }
-#endif
 
-GtkWidget *
+static GtkWidget *
 ToolbarAddWidget(GtkToolbar * pwToolbar, GtkWidget * pWidget, const char *tooltip)
 {
     GtkToolItem *ti = gtk_tool_item_new();
@@ -350,7 +348,6 @@ ToolbarAddWidget(GtkToolbar * pwToolbar, GtkWidget * pWidget, const char *toolti
     return GTK_WIDGET(ti);
 }
 
-#if !defined(USE_GTKUIMANAGER)
 static void
 ToolbarAddSeparator(GtkToolbar * pwToolbar)
 {
@@ -368,6 +365,7 @@ ToolbarNew(void)
 
     pwToolbar = gtk_ui_manager_get_widget(puim, "/MainToolBar");
     g_object_set_data_full(G_OBJECT(pwToolbar), "toolbarwidget", ptw, g_free);
+    gtk_toolbar_set_style(GTK_TOOLBAR(pwToolbar), GTK_TOOLBAR_BOTH);
 
     ptw->pwNew = gtk_ui_manager_get_widget(puim, "/MainToolBar/New");
     gtk_tool_item_set_homogeneous(GTK_TOOL_ITEM(ptw->pwNew), TRUE);
