@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: neuralnet.c,v 1.87 2016/06/05 20:01:42 plm Exp $
+ * $Id: neuralnet.c,v 1.91 2017/08/13 20:29:16 plm Exp $
  */
 
 #include "config.h"
@@ -33,7 +33,7 @@
 #include "simd.h"
 #include "sigmoid.h"
 
-extern int
+static int
 NeuralNetCreate(neuralnet * pnn, unsigned int cInput, unsigned int cHidden,
                 unsigned int cOutput, float rBetaHidden, float rBetaOutput)
 {
@@ -236,7 +236,7 @@ NeuralNetEvaluate(const neuralnet * pnn, float arInput[], float arOutput[], NNSt
     case NNEVAL_FROMBASE:
         {
             unsigned int i;
-            if (pnState->cSavedIBase != (int) pnn->cInput) {
+            if (pnState->cSavedIBase != pnn->cInput) {
                 Evaluate(pnn, arInput, ar, arOutput, 0);
                 break;
             }
@@ -373,6 +373,8 @@ SIMD_Supported(void)
 
 #else
 
+#if defined(HAVE_SSE)
+
 #if defined(__APPLE__) || defined(__FreeBSD__)
 #include <sys/sysctl.h>
 #endif
@@ -500,7 +502,6 @@ CheckSSE(void)
 #endif
     if (0 != error)
         result = 0;
-    return result;
 
 #else
 
@@ -547,13 +548,19 @@ CheckSSE(void)
     return result;
 }
 
+#endif /* HAVE_SSE */
+
 int
 SIMD_Supported(void)
 {
     static int state = -3;
 
     if (state == -3)
+#if defined(HAVE_SSE)
         state = CheckSSE();
+#else
+        state = -2;
+#endif
 
     return state;
 }
