@@ -1,7 +1,7 @@
 /*
  * makehyper.c
  *
- * by Jrn Thyssen <jth@gnubg.org>, 2003
+ * by Joern Thyssen <jth@gnubg.org>, 2003
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 3 or later of the GNU General Public License as
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: makehyper.c,v 1.49 2015/10/14 21:29:40 plm Exp $
+ * $Id: makehyper.c,v 1.51 2017/11/09 22:15:31 plm Exp $
  */
 
 #include "config.h"
@@ -152,6 +152,7 @@ StartGuessHyper(hyperequity ahe[], const int nC, bearoffcontext * UNUSED(pbc))
             case HYPER_CONTACT:
                 ++ai[1];
                 --ai[2];
+                /* FALLTHRU */
             case HYPER_BEAROFF:
 
                 memset(&ahe[i * nPos + j], 0, sizeof(hyperequity));
@@ -473,7 +474,7 @@ CalcNewEquity(hyperequity ahe[], const int nC, float arNorm[])
 
     for (i = 0; i < nPos; ++i) {
 
-        printf("\r%d/%d              ", i, nPos);
+        printf("\r%d/%d              ", i + 1, nPos);
         fflush(stdout);
 
         for (j = 0; j < nPos; ++j) {
@@ -674,7 +675,7 @@ main(int argc, char **argv)
 
     printf(_("Time for start guess: %d seconds\n"), (int) (t1 - t0));
 
-    it = 0;
+    it = 1;
 
     do {
 
@@ -713,6 +714,9 @@ main(int argc, char **argv)
 
     printf(_("Time for writing final file: %d seconds\n"), (int) (t1 - t0));
 
+    free(aheEquity);
+    g_free(szOutput);
+
     time(&t3);
 
     printf(_("Total time: %d seconds\n"), (int) (t3 - t2));
