@@ -20,7 +20,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: osr.c,v 1.36 2013/07/10 20:51:46 mdpetch Exp $
+ * $Id: osr.c,v 1.39 2016/05/11 21:33:08 plm Exp $
  */
 
 /*lint -e514 */
@@ -38,8 +38,8 @@
 #define MAX_PROBS        32
 #define MAX_GAMMON_PROBS 15
 
-static unsigned long mt[N];
-static int mti = N + 1;
+static unsigned long mt[MT_ARRAY_N];
+static int mti = MT_ARRAY_N + 1;
 
 static unsigned int
 OSRQuasiRandomDice(const unsigned int iTurn, const unsigned int iGame, const unsigned int cGames,
@@ -63,7 +63,7 @@ OSRQuasiRandomDice(const unsigned int iTurn, const unsigned int iGame, const uns
 /* Fill aaProb with one sided bearoff probabilities for position with */
 /* bearoff id n.                                                      */
 
-static inline void
+static void
 getBearoffProbs(const unsigned int n, unsigned short int aaProb[32])
 {
     g_assert(pbc1);
@@ -822,7 +822,7 @@ raceProbs(const TanBoard anBoard, const unsigned int nGames, float arOutput[NUM_
 
     float w, s;
 
-    /* Seed set to ensure that OSR are reproducable */
+    /* Seed set to ensure that OSR are reproducible */
 
     init_genrand(0, &mti, mt);
 
