@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: rollout.c,v 1.249 2015/11/02 20:29:23 plm Exp $
+ * $Id: rollout.c,v 1.253 2017/08/16 19:36:19 plm Exp $
  */
 
 #include "config.h"
@@ -43,6 +43,8 @@
 #include "rollout.h"
 #include "lib/simd.h"
 
+#define LogCubeClamped(n) (n < (1 << STAT_MAXCUBE) ? LogCube(n) : (STAT_MAXCUBE - 1))
+
 #if !defined(LOCKING_VERSION)
 
 f_BasicCubefulRollout BasicCubefulRollout = BasicCubefulRolloutNoLocking;
@@ -116,7 +118,7 @@ board_to_sgf(FILE * logfp, const unsigned int anBoard[25], int direction)
         fprintf(logfp, "[y]");
 }
 
-extern FILE *
+static FILE *
 log_game_start(const char *name, const cubeinfo * pci, int fCubeful, TanBoard anBoard)
 {
     time_t t = time(0);
@@ -169,7 +171,7 @@ log_game_start(const char *name, const cubeinfo * pci, int fCubeful, TanBoard an
     return logfp;
 }
 
-extern void
+static void
 log_game_over(FILE * logfp)
 {
     if (!logfp)
@@ -178,7 +180,7 @@ log_game_over(FILE * logfp)
     fclose(logfp);
 }
 
-extern void
+static void
 QuasiRandomSeed(perArray * pArray, int n)
 {
 
@@ -241,7 +243,7 @@ RolloutDice(int iTurn, int iGame,
                 int n;
                 if ((n = RollDice(anDice, rngx, rngctx)) != 0)
                     return n;
-            } while (fInitial && !iTurn && anDice[0] == anDice[1]);
+            } while (anDice[0] == anDice[1]);
 
             return 0;
         }
@@ -478,7 +480,7 @@ BasicCubefulRollout(unsigned int aanBoard[][2][25],
 
                         /* update statistics */
                         if (aarsStatistics)
-                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acDoubleTake[LogCube(pci->nCube)]);
+                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acDoubleTake[LogCubeClamped(pci->nCube)]);
 
                         SetCubeInfo(pci, 2 * pci->nCube, !pci->fMove, pci->fMove, pci->nMatchTo,
                                     pci->anScore, pci->fCrawford, pci->fJacoby, pci->fBeavers, pci->bgv);
@@ -516,8 +518,8 @@ BasicCubefulRollout(unsigned int aanBoard[][2][25],
                         /* update statistics */
 
                         if (aarsStatistics) {
-                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acDoubleDrop[LogCube(pci->nCube)]);
-                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acWin[LogCube(pci->nCube)]);
+                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acDoubleDrop[LogCubeClamped(pci->nCube)]);
+                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acWin[LogCubeClamped(pci->nCube)]);
                         };
 
                         break;
@@ -757,13 +759,13 @@ BasicCubefulRollout(unsigned int aanBoard[][2][25],
                     if (aarsStatistics)
                         switch (GameStatus((ConstTanBoard) aanBoard[ici], pci->bgv)) {
                         case 1:
-                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acWin[LogCube(pci->nCube)]);
+                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acWin[LogCubeClamped(pci->nCube)]);
                             break;
                         case 2:
-                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acWinGammon[LogCube(pci->nCube)]);
+                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acWinGammon[LogCubeClamped(pci->nCube)]);
                             break;
                         case 3:
-                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acWinBackgammon[LogCube(pci->nCube)]);
+                            MT_SafeInc(&aarsStatistics[ici][pci->fMove].acWinBackgammon[LogCubeClamped(pci->nCube)]);
                             break;
                         }
 
