@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: text.c,v 1.111 2015/09/26 20:20:13 plm Exp $
+ * $Id: text.c,v 1.114 2017/04/04 04:49:32 plm Exp $
  */
 
 #include "config.h"
@@ -81,7 +81,7 @@ printTextBoard(FILE * pf, const matchstate * pms)
         apch[pms->fMove ? 4 : 2] = sz;
 
         if (pms->anDice[0])
-            sprintf(sz, _("Rolled %d%d"), pms->anDice[0], pms->anDice[1]);
+            sprintf(sz, _("Rolled %u%u"), pms->anDice[0], pms->anDice[1]);
         else if (!GameStatus((ConstTanBoard) anBoard, pms->bgv))
             strcpy(sz, _("On roll"));
         else
@@ -91,7 +91,12 @@ printTextBoard(FILE * pf, const matchstate * pms)
             apch[3] = szCube;
 
             if (pms->nMatchTo)
-                sprintf(szCube, _("%d point match (Cube: %d)"), pms->nMatchTo, pms->nCube);
+                if (pms->nMatchTo == 1)
+                    sprintf(szCube, _("1 point match"));
+                else if (pms->fCrawford)
+                    sprintf(szCube, _("%d point match (Crawford game)"), pms->nMatchTo);
+                else
+                    sprintf(szCube, _("%d point match (Cube: %d)"), pms->nMatchTo, pms->nCube);
             else
                 sprintf(szCube, _("(Cube: %d)"), pms->nCube);
         } else {
@@ -160,7 +165,7 @@ TextBoardHeader(GString * gsz, const matchstate * pms, const int UNUSED(iGame),
 
         /* chequer play decision */
 
-        g_string_append_printf(gsz, _(" %s to play %d%d\n\n"), ap[pms->fMove].szName, pms->anDice[0], pms->anDice[1]
+        g_string_append_printf(gsz, _(" %s to play %u%u\n\n"), ap[pms->fMove].szName, pms->anDice[0], pms->anDice[1]
             );
 
     else if (pms->fDoubled)
@@ -224,7 +229,7 @@ TextEpilogue(FILE * pf, const matchstate * UNUSED(pms))
 
     time_t t;
 
-    const char szVersion[] = "$Revision: 1.111 $";
+    const char szVersion[] = "$Revision: 1.114 $";
     int iMajor, iMinor;
 
     iMajor = atoi(strchr(szVersion, ' '));
@@ -434,7 +439,7 @@ TextPrintMoveAnalysis(GString * gsz, const matchstate * pms, moverecord * pmr)
 
     g_string_append(gsz, "\n");
 
-    g_string_append_printf(gsz, _("Rolled %d%d"), pmr->anDice[0], pmr->anDice[1]);
+    g_string_append_printf(gsz, _("Rolled %u%u"), pmr->anDice[0], pmr->anDice[1]);
 
     if (pmr->rLuck != ERR_VAL)
         g_string_append_printf(gsz, " (%s):\n", GetLuckAnalysis(pms, pmr->rLuck));
@@ -846,7 +851,6 @@ CommandExportMatchText(char *sz)
     }
 
     /* Find number of games in match */
-
     for (pl = lMatch.plNext, nGames = 0; pl != &lMatch; pl = pl->plNext, nGames++);
 
     for (pl = lMatch.plNext, i = 0; pl != &lMatch; pl = pl->plNext, i++) {
@@ -855,8 +859,10 @@ CommandExportMatchText(char *sz)
 
         if (!i) {
 
-            if (!confirmOverwrite(sz, fConfirmSave))
+            if (!confirmOverwrite(sz, fConfirmSave)) {
+                g_free(szCurrent);
                 return;
+            }
 
             setDefaultFileName(sz);
 
@@ -867,6 +873,7 @@ CommandExportMatchText(char *sz)
             pf = stdout;
         else if ((pf = gnubg_g_fopen(szCurrent, "w")) == 0) {
             outputerr(szCurrent);
+            g_free(szCurrent);
             return;
         }
 
@@ -875,6 +882,7 @@ CommandExportMatchText(char *sz)
         if (pf != stdout)
             fclose(pf);
 
+        g_free(szCurrent);
     }
 
 }
